function wim = imageWT2D(w,nL,mL,gamma)

% imageWT2D -- creates image of 2D wavelet transform for display
%  Usage
%     image(imageWT2D(w,nL,mL,gamma))
%     wim = imageWT2D(w,nL,mL,gamma)
%  Inputs
%     w        matrix containing 2D (squared or rectangular) WT
%     nL x mL  size of coarse scaling coefficient submatrix
%     gamma    (default 3) gamma correction
%  Outputs
%     wim      integer matrix of size(w), for use as image

if nargin<4, gamma=3; end
if nargin<2, nL = NaN; mL = NaN; end
if isnan(nL),
   [n m] = size(w);
   J = ceil(log2(min(n,m))); jj = (J:-1:0);
   nL = ceil(n./2.^jj); mL = ceil(m./2.^jj);
   medianabswL = zeros(1,J+1);
   for j=jj, medianabswL(j+1) = median(abs(w(1:nL(j+1),1:mL(j+1))),'all'); end
   [dummy L] = max(abs(medianabswL(2:J+1)-medianabswL(1:J))); 
   nL = nL(L); mL = mL(L);
end
wim = abs(w);
wim(1:nL,1:mL) = 0;
R = max(max(wim));
wim = 256*((R-wim)/R).^gamma;

R = max(max(abs(w(1:nL,1:mL))));
wim(1:nL,1:mL) = round(w(1:nL,1:mL)*256/R);
