% Makes Figure 1 of the Introduction

% Output settings
fontopt = {'fontsize',16,'fontweight','bold'};
rightal = {'horizontalalignment','right'};
topal = {'verticalalignment','top'};
if exist('makefigfile') ~= 1, makefigfile = false; end
if exist('ext') ~= 1, ext = 'eps'; end
dext = ['-d' ext];
figsize = [960 480]; 
figsize = [800 420];
papersize = figsize/96; figpaperpos = [0 0 papersize];

% Sparse model setting (mixture prior: zero inflated double exponential)
n = 2000;
p = 0.05;
a = 1/5;
np = ceil(n*p);
stdev = 1;

rand('state',0)
randn('state',0)

beta = zeros(1,n);
beta(1:np) = randlaplace(1,np,a);
beta = beta(randperm(n));
betasort = sort(abs(beta),'descend');

Z = randn(size(beta));

Y = beta+stdev*Z;
Ysort = sort(abs(Y),'descend');

% threshold values tt in which MSE (=PE, prediction error) will be calculated
k = (1:n);
tt = Ysort(k);

% PE of hard and soft thresholding
PEhard = MSE1thresh(beta,Y,tt,'H');
PEsoft = MSE1thresh(beta,Y,tt,'S');
gcv = GCV1soft(Y,tt);

figure(1)
plot(k,PEhard,'linewidth',3,'color',[1 1 1]*0.2)
% axy = axis; axy(2) = axy(2)*1.1; axis(axy);
axy = axis; axy(2) = axy(2)/3; axy(4) = 0.7*axy(4);
PEhard(PEhard>axy(4)*0.95) = NaN;
plot(k,PEhard,'linewidth',4,'color',[1 1 1]*0.2)
axis(axy)
axis off
figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)

nt = 10; xticks = bestticks(0,n,nt);
drawaxes('xtick',xticks,fontopt{:})
text(axy(2),axy(4)*0.05,'model size',fontopt{:},rightal{:})
% text(axy(2)*0.05,axy(4),'PE = bias^2+variance',fontopt{:},topal{:})
% bias^2 leads to gap/whitespace when printing to pdf/eps in Matlab (unsolved)
text(axy(2)*0.05,axy(4),'\textbf{PE = bias$^2$+variance}',fontopt{:},topal{:},'Interpreter','latex')

if makefigfile==true,
   fnameout = ['PE00.' ext];
   print(dext,fnameout);
else
   disp('No file has been printed. Set makefigfile=true; to generate it')
   disp('Set ext=''eps''; to create eps files and ext=''eps''; for pdf files')
end

% Estimate PE using GCV (not in Figure 1 of the Introduction)
figure(2)
% PEsoft(PEsoft>axy(4)*0.95) = NaN;
% gcv(gcv>axy(4)*0.95) = NaN;
plot(k,PEhard,'linewidth',3,'color',[1 1 1]*0.2)
hold on
plot(k,PEsoft,'linewidth',3,'color','k')
plot(k,gcv-stdev^2,':','linewidth',3,'color','k')
hold off
axy(2) = 2*axy(2);
axis(axy)
axis off
drawaxes('xtick',round((1:nt)/nt*n),fontopt{:})
text(axy(2),axy(4)*0.05,'model size',fontopt{:},rightal{:})
text(axy(2)*0.05,axy(4),'PE = bias^2+variance',fontopt{:},topal{:})

