% ThreshLab/BookWavelets/Chapters01/makefigsskylinechap01haar.m
% Makes Figures 1.9, 1.10, 1.11, 1.13, 1.14, 1.15, 1.16

% first define/declare default values
if exist('makeeps') ~= 1, makeeps = false; end
if exist('makepdf') ~= 1, makepdf = false; end
if makepdf==true,
   ext='.pdf'; makeeps = false;
elseif makeeps==true,
   ext='.eps'; 
end
% if exist('figsize') ~= 1, figsize = [840 420]; end
if exist('figsize') ~= 1, figsize = [960 480]; end
figpaperpos = [0 0 figsize/96];
figsize0 = [560 420];
if exist('samplesize') ~= 1, samplesize = 2000; end
if exist('realrandom') ~= 1, realrandom = false; end
if realrandom==false, rand('state',0); randn('state',0); end
if exist('linewidth') ~= 1, linewidth = 3; end
if exist('fontsize') ~= 1, fontsize = 18; end
lineBWopt = {'color','k','linewidth',linewidth};
textopt = {'fontsize',fontsize,'fontweight','bold'};
lineRGBopt = {'color','b','linewidth',linewidth};
dotplotopt = {'ko','markersize',4,'markerfacecolor','k'};
% {'marker','o','markersize',4,'markeredgecolor','k','markerfacecolor','k'};

% Generate test signal for simulation
n = samplesize;
x = column(makegrid(n,0)); % equidistant knots
% f = makesignal(x,'heavisine');
f = makesignal(x,'skyline');
y = makenoisy(f,10);

% Compute M=8 resolution levels of the Forward Haar transform 
% Haar is special case of Deslauriers-Dubuc, polynomial interpolation, with
% dual vanishing moments pt=1 and primal vanishing moments p = 1)
% Compute coefficients with noise (w) and without noise (v)
pt = 1;
p = 1;
M = 8;
w = FWT2G1D(x,y,'DD',pt,p,M);
v = FWT2G1D(x,f,'DD',pt,p,M);

J = ceil(log2(n)); L = J-M;

% Now find the transformation matrix: apply the routine to the identity matrix
I = sparse(eye(n));
Wt = FWT2G1D(x,I,'DD',pt,p,M);
% Covariance matrix of wavelet-coefficients is Wt*cov(input)*Wt'
% Here the input is homescedastic and uncorrelated: cov(input) = I
% Extract diagonal: stdev of coefficients
stdevw = column(sqrt(diag(Wt*Wt')));
w = w./stdevw;
v = v./stdevw;
stdev = sqrt(mean((w-v).^2));

% Find minimum risk hard threshold (oracular value; unknown in real life)
thr = minriskhardthr(v,stdev);
wthr = HT(w,thr);

fhat = IWT2G1D(x,wthr.*stdevw,'DD',pt,p,M);

njj(1) = n;
xeven = x;
for j =2:M, xeven = xeven(splitevenodd(xeven)); njj(j) = length(xeven); end
   
plotasblocks(x,y,lineRGBopt{:})
ay = axis;
ay(3) = -2; ay(4) = 12;

axis([0 1 ay(3) ay(4)])

figpos = get(gcf,'position');
figpos(3:4) = figsize;
set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Covariate values',textopt{:})
ylabel('Observed values',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['observedsignaln' num2str(n) ext];
else
   disp('Press any key to continue (1)')
   pause
end
if makeeps==true, print('-depsc',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotasblocks(x,y,lineBWopt{:})
ay = axis;
ay(3) = -2; ay(4) = 12;

axis([0 1 ay(3) ay(4)])

set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Covariate values',textopt{:})
ylabel('Observed values',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['observedsignaln' num2str(n) 'grey' ext];
end
if makeeps==true, print('-deps',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotasblocks(x,f,lineRGBopt{:})
axis([0 1 ay(3) ay(4)])

set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Covariate values',textopt{:})
ylabel('Error-free values',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['errorfreesignaln' num2str(n) ext];
else
   disp('Press any key to continue (2)')
   pause
end
if makeeps==true, print('-depsc',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotasblocks(x,f,lineBWopt{:})
axis([0 1 ay(3) ay(4)])

set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Covariate values',textopt{:})
ylabel('Error-free values',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['errorfreesignaln' num2str(n) 'grey' ext];
end
if makeeps==true, print('-deps',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plot(w(njj(M-1)+1:n))
aw = axis;
maxy = max(abs(aw(3:4))); miny = -maxy;
plotresolutionlevels(v,L,miny,maxy,lineBWopt{:},'fillcolor')
set(gcf,'position',figpos)
set(gcf,'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Scale (by color) + location',textopt{:})
ylabel('Wavelet coefficients',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['errfreeHaarcoefn' num2str(n) 'coloredscales' ext];
else
   disp('Press any key to continue (3)')
   pause
end
if makeeps==true, print('-depsc',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plot(w(njj(M-1)+1:n))
aw = axis;
maxy = max(abs(aw(3:4))); miny = -maxy;
plotresolutionlevels(v,L,miny,maxy,lineBWopt{:},'fillgrey')
set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Scale (by grey level) + location',textopt{:})
ylabel('Wavelet coefficients',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['errfreeHaarcoefn' num2str(n) 'greylevelscales' ext];
end
if makeeps==true, print('-deps',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotresolutionlevels(w,L,miny,maxy,lineBWopt{:},'fillcolor')
set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Scale (by color) + location',textopt{:})
ylabel('Wavelet coefficients',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['observedHaarcoefn' num2str(n) 'coloredscales' ext];
else
   disp('Press any key to continue (4)')
   pause
end
if makeeps==true, print('-depsc',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotresolutionlevels(w,L,miny,maxy,lineBWopt{:},'fillgrey')
set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Scale (by grey level) + location',textopt{:})
ylabel('Wavelet coefficients',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['observedHaarcoefn' num2str(n) 'greylevelscales' ext];
end
if makeeps==true, print('-deps',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotresolutionlevels(wthr,L,miny,maxy,lineBWopt{:},'fillcolor')
set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Scale (by color) + location',textopt{:})
ylabel('Wavelet coefficients',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['thresholdedHaarcoefn' num2str(n) 'coloredscales' ext];
else
   disp('Press any key to continue (5)')
   pause
end
if makeeps==true, print('-depsc',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotresolutionlevels(wthr,L,miny,maxy,lineBWopt{:},'fillgrey')
set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Scale (by grey level) + location',textopt{:})
ylabel('Wavelet coefficients',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['thresholdedHaarcoefn' num2str(n) 'greylevelscales' ext];
end
if makeeps==true, print('-deps',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotasblocks(x,fhat,lineRGBopt{:})
axis([0 1 ay(3) ay(4)])

set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Covariate values',textopt{:})
ylabel('Estimated values',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['estimatedsignaln' num2str(n) ext];
else
   disp('Press any key to continue (6)')
   pause
end
if makeeps==true, print('-depsc',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

plotasblocks(x,fhat,lineBWopt{:})
axis([0 1 ay(3) ay(4)])

set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Covariate values',textopt{:})
ylabel('Estimated values',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
   fnameout = ['estimatedsignaln' num2str(n) 'grey' ext];
end
if makeeps==true, print('-deps',fnameout); end
if makepdf==true, print('-dpdf',fnameout); end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Fourier filtering %%%
%%%%%%%%%%%%%%%%%%%%%%%%%

close all

F = fft(f);
F = fftshift(F);
plot(-ceil(n/2)+1:floor(n/2),abs(F),lineBWopt{:})
hold on
plot(-ceil(n/2):floor(n/2)-1,abs(F),dotplotopt{:})
hold off

axFourier = axis; axFourier(4) = axFourier(4)/2; axFourier(1:2) = [-1 1]*100;
xticks = [axFourier(1)+10 0 axFourier(2)-10];
axis(axFourier)
axis off, drawaxes('xticks',xticks,textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
else
   disp('Press any key to continue (7)')
   pause
end
if makeeps==true, print -depsc spectrumskylinef.eps, end
if makepdf==true, print -dpdf spectrumskylinef.pdf, end

Y = fft(y);
Y = fftshift(Y);
plot(-ceil(n/2)+1:floor(n/2),abs(Y),lineBWopt{:})
hold on
plot(-ceil(n/2):floor(n/2)-1,abs(Y),dotplotopt{:})
hold off
axis(axFourier)
axis off, drawaxes('xticks',xticks,textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
else
   disp('Press any key to continue (8)')
   pause
end
if makeeps==true, print -depsc spectrumskyliney.eps, end
if makepdf==true, print -dpdf spectrumskyliney.pdf, end

% filter away high frequencies
cutoff = 0.07;
window = zeros(size(Y));
windowlowerbound = floor(n/2-cutoff*n/2);
windowupperbound = ceil(n/2+cutoff*n/2);
window(windowlowerbound:windowupperbound) = 1;
Yfilt = Y.*window;
plot(-ceil(n/2)+1:floor(n/2),abs(Yfilt),lineBWopt{:})
hold on
plot(-ceil(n/2):floor(n/2)-1,abs(Yfilt),dotplotopt{:})
hold off
axis(axFourier)
axis off, drawaxes('xticks',xticks,textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
else
   disp('Press any key to continue (8)')
   pause
end
if makeeps==true, print -depsc filteredspectrumskyliney.eps, end
if makepdf==true, print -dpdf filteredspectrumskyliney.pdf, end

% inverse transformatie
Yfilt = ifftshift(Yfilt);
yfilt = abs(ifft(Yfilt));

plotasblocks(x,yfilt,lineBWopt{:})

axis([0 1 ay(3) ay(4)])
set(gcf,'position',figpos)
set(gcf, 'PaperPosition',figpaperpos)
set(gca,textopt{:})
xlabel('Covariate values',textopt{:})
ylabel('Estimated values',textopt{:})
if makeeps==true | makepdf==true,
   makefigtransparent
else
   disp('No figs printed. Set makeeps=true; or makepdf=true; to generate them')
end
if makeeps==true, print -depsc filteredskyliney.eps, end
if makepdf==true, print -dpdf filteredskyliney.pdf, end
