
% Makes Figure 2.12 (default settings)
% (but does more than that)
% Makes Figure 3.4 by running:
%   dualmom = 2; primalmom = [0 Inf]; makefigBsplineduals


if exist('makeepsfiles') ~= 1, makeepsfiles = false; end
if exist('knotsasinbook') ~= 1, knotsasinbook = true; end
if exist('realrandomknots') ~= 1, realrandomknots = false; end
if realrandomknots == false, rand('state',0), end
if exist('equispacedknots') ~= 1, equispacedknots = false; end
if exist('dualmom') ~= 1, dualmom = 2; end
if exist('primalmom') ~= 1, primalmom = 2; end
if exist('compareregular') ~= 1, compareregular = false; end
if exist('nknots') ~= 1, nknots = dualmom+sum(primalmom)+3; end
if exist('Lk') ~= 1, Lk = 5; end
if exist('displayht') ~= 1, displayht = true; end
if exist('nn') ~= 1, nn = 1000; end
if exist('nLmax') ~= 1, nLmax = 40; end
if exist('figsize') ~= 1, figsize = [1280 420]; end
if exist('papersize') ~= 1, papersize = figsize/96; end
if exist('figpaperpos') ~= 1, figpaperpos = [0 0 papersize]; end

ptilde = dualmom;
p = primalmom;


knotplotoptions = ...
          {'o','markersize',12,'markeredgecolor','k','markerfacecolor','k'};
lineplotoptions = {'linewidth',3,'color','k'};
nL = min(nknots,nLmax);
xx = (1:nn)/nn;

if exist('knots') == 1,
   knots = column(knots); nknots = length(knots); nL = nknots;
elseif knotsasinbook==true,
   chooseknotsasinbook; knots = knots12;
   nknots = 12; nL = nknots;
elseif equispacedknots == true,
   knots = (0:nL-1)/(nL-1);
else
   knots = sort(rand(1,nL));
   % knots = makegrid(nL,1,true);
   knots = (knots-knots(1))/(knots(nL)-knots(1));
   % knots = [knots(1) knots knots(nL)];
end

PhiB = Bsplinebasis(xx,knots,ptilde);
PhiBknots = Bsplinebasis(knots,knots,ptilde,false);
PhiBbyrefinement = Bsplinebasisbyrefinement(xx,knots,ptilde,false);
x = knots; n = length(x); M = 0;
while n < nn,
   M = M+1;
   u = (x(1:n-1)+x(2:n))/2;
   n = 2*n-1;
   xu = zeros(1,n);
   xu(1:2:n) = x;
   xu(2:2:n) = u;
   x = xu;
end
I = [eye(nL); zeros(n-nL,nL)];
PhiBiwt = IWT2G1D(x,I,'Bspline',ptilde,p,M);
PhiBtilde = FWT2G1D(x,eye(n),'Bspline',ptilde,p,M)'; 
% The size of I fixes the orientation of PhiBiwt (basisfunction in the columns)
% As eye(n) is square, we have to force the result to have the basisfunctions
% in the columns.
PsiBtilde = PhiBtilde(1:n,nL+1:2*nL);
PhiBtilde = PhiBtilde(1:n,1:nL);
if equispacedknots == true,
   Wt1 = FWT2G1D(x,eye(n),'Bspline',ptilde,p,1);
   Ht = Wt1(1:2:n,1:n);
   ht = Ht(floor(n/4),1:n);
   nonzeros = find(abs(ht)>eps);
   s1 = min(nonzeros); s2 = max(nonzeros); ht = ht(s1:s2);
   if displayht==true, ht, end
end
I = [zeros(nL,nL-1); eye(nL-1,nL-1); zeros(n-2*nL+1,nL-1)];
PsiBiwt = IWT2G1D(x,I,'Bspline',ptilde,p,M);
vanmomJ = Bsplinemoments(x,ptilde,(0:p(1)),false);
vanmomL = PsiBiwt'*vanmomJ
vanmomPhiL = PhiBiwt'*vanmomJ
dualvanmomJ = allpowercoefsBsplines(x,ptilde);
dualvanmomL = PsiBtilde'*dualvanmomJ

% compare to regular grid:
if compareregular == true,
   J = ceil(log2(n));
   n2 = 2^J;
   L = J-M;
   [h ht] = makeWTfilter('CDF',ptilde,p);
   % Attention: makeWTfilter and FWT_BIO call p the number of vanishing moments
   % for the family of B-splines. These are actually the DUAL vanishing moments
   [h, g, ht, gt, sh, sg, sht, sgt] = mirrorshifts(h,ht);
   PhiBtilde2 = FWT_BIO(eye(n2),L,ht,gt,sht,sgt)';
   PhiBtilde2 = PhiBtilde2(1:2^L,1:n2);
   plot(1:n2,PhiBtilde2)
   plot(1:n2,PhiBtilde2(5,:))
end

plot(x,PhiBtilde(1:n,Lk),lineplotoptions{:})
hold on
plot(knots,zeros(size(knots)),knotplotoptions{:})
% plot(knots([1 nL]),[1 1],knotplotoptions{:})
hold off
axis off
% axy = axis; axy(1:2) = [-0.05 1.1]; axy(4) = axy(4)*1.1; axis(axy)
axy = axis; axy(2) = 1.1; axy(4) = min(axy(4),1.2); 
axy(3) = max(axy(3),-axy(4));
axis(axy);
figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
drawaxes
if makeepsfiles == true,
   fname = ['dualBsplinebasis' num2str(p) '-' num2str(ptilde) '.eps'];
   makefigtransparent
   print('-deps',fname);
end

if makeepsfiles == false,
   message1 = 'no eps files have been printed. Set makeepsfiles = true;';
   message2 = ' to print eps files.';
   disp([message1 message2])
end

