% Makes Figures 1.8
if exist('makeepsfiles') ~= 1, makeepsfiles = false; end
if exist('randomknots') ~= 1, randomknots = false; end
if exist('knotsasinbook') ~= 1, knotsasinbook = true; end
if exist('nn') ~= 1, nn = 1000; end
if exist('figsize') ~= 1, figsize = [1280 420]; end
if exist('papersize') ~= 1, papersize = figsize/96; end
if exist('figpaperpos') ~= 1, figpaperpos = [0 0 papersize]; end

knotopt = {'ko','markersize',12,'markerfacecolor','k'};
% i.e.:   {'o','markersize',12,'markeredgecolor','k','markerfacecolor','k'};
lineopt = {'linewidth',3,'color','k'};

if exist('knots'),
   knots = column(knots); nknots = length(knots);
elseif knotsasinbook==true,
   chooseknotsasinbook; knots = knots7;
   nknots = 7;
else
   if randomknots == false, rand('state',2), end
   if exist('nknots') ~= 1, nknots = 7; end
   knots = sort(rand(nknots,1));
   knots = (knots-knots(1))/(knots(nknots)-knots(1));
end
nL = nknots;
xx = (1:nn)/nn;

for ptilde = 1:4,
   PhiB = Bsplinebasis(xx,knots,ptilde);
   PhiBknots = Bsplinebasis(knots,knots,ptilde,false);
   if ptilde == 0,
      plotasblocks([xx 1],[PhiB; zeros(1,ptilde+nL-2)],lineopt{:})
   else
      plot([xx 1],[PhiB; zeros(1,ptilde+nL-2)],lineopt{:})
   end
   hold on
   plot(knots,zeros(size(knots)),knotopt{:})
   plot(knots,diag(PhiBknots),knotopt{:})
   % plot(knots(n)*[1 1],[0 1],lineopt{:})
   plot(knots([1 nL]),[1 1],knotopt{:})
   hold off
   axis off
   % axy = axis; axy(1:2) = [-0.05 1.1]; axy(4) = axy(4)*1.1; axis(axy)
   axy = axis; axy(2) = 1.1; axy(4) = 1.2; axis(axy);
   figpos = get(gcf,'position'); figpos(3:4) = figsize;
   set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
   drawaxes
   if makeepsfiles == true,
      fname = ['Bsplinebasis' num2str(ptilde) '.eps'];
      print('-deps',fname);
   else
      disp(['Bspline basis of order ' num2str(ptilde) '; Press any key.'])
      pause
   end
end

if makeepsfiles == false,
   message1 = 'no eps files have been printed. Set makeepsfiles = true;';
   message2 = ' to print eps files.';
   disp([message1 message2])
end

