
% Makes Figures 3.6 and 3.7

if exist('randomknots') ~= 1, randomknots = false; end
if exist('mirrorextension') ~= 1, mirrorextension = true; end
if exist('ptilde') ~= 1, ptilde = 4; end
if exist('makeeps') ~= 1, makeeps = false; end
if exist('pauseon') ~= 1, pauseon = false; end

if exist('knotsasinbook') ~= 1, knotsasinbook = true; end
if exist('nn') ~= 1, nn = 1000; end
if exist('figsize') ~= 1, figsize = [1280 420]; end
if exist('papersize') ~= 1, papersize = figsize/96; end
if exist('figpaperpos') ~= 1, figpaperpos = [0 0 papersize]; end

knotopt = {'ko','markersize',12,'markerfacecolor','k'};
% i.e.:   {'o','markersize',12,'markeredgecolor','k','markerfacecolor','k'};
lineopt = {'linewidth',3,'color','k'};

if exist('knots')==1,
   knots = column(knots); nknots = length(knots);
elseif knotsasinbook==true,
   chooseknotsasinbook; knots = knots7;
   nknots = 7;
else
   if randomknots == false, rand('state',2), end
   if exist('nknots') ~= 1, nknots = max(7,2*ptilde-1); end
   knots = sort(rand(nknots,1));
   knots = (knots-knots(1))/(knots(nknots)-knots(1));
end
nL = nknots;
xx = (1:nn)/nn;

knotopt = {'ko','markersize',12,'markerfacecolor','k'};
% i.e.:   {'o','markersize',12,'markeredgecolor','k','markerfacecolor','k'};
lineopt = {'linewidth',3,'color','k'};

if ptilde ~= 4, makeeps = false; end
begincomments = true;
endcomments = false;
commentsline = '------------------------------------------------------------';
if makeeps == false,
   disp(commentsline)
   disp('No eps will be printed. Type makeeps = true; for eps outputs')
   begincomments = false;
   endcomments = true;
end
if mirrorextension == false,
   if begincomments == true, disp(commentsline), end
   disp('Boundary effects will be visible. Type mirrorextension = true')
   endcomments = true;
end
if endcomments == true, disp(commentsline), end
ptc = ceil((ptilde-1)/2); ptf = floor((ptilde-1)/2);

x = knots;
kL = max(3,ptilde); kL0 = kL;
knots0 = knots;
if mirrorextension == true,
   x = [-x(nL:-1:2); x; 2-x(nL-1:-1:1)]; kL = kL+nL-1; nL = 3*nL-2;
   knots = x;
   a = -0.1; b = 1.1; xx = a+(b-a)*xx;
end
PhiDD = DDbasisbyrefinement(xx,knots,ptilde);
plot(xx,PhiDD,lineopt{:})
hold on
plot(knots,zeros(size(knots)),knotopt{:})
plot(knots,ones(size(knots)),knotopt{:})
plot(knots(nknots)*[1 1],[0 1],lineopt{:})
plot(knots([1 nknots]),[1 1],knotopt{:})
hold off
axy = [-0.1 1.1 -1.2 1.8]; axis(axy)
axis off

figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)

drawaxes

pausenr = 0;
if makeeps==true,
   makefigtransparent
   print -deps DeslauriersDubuc4basis.eps,
else
   pausenr = pausenr+1;
   disp(['Press any key to continue (' num2str(pausenr) ')'])
   pause
end

evenopt = {'rs','markersize',18,'markerfacecolor','k','markeredgecolor','k'};
oddopt = {'o','markersize',12,'markerfacecolor','white',...
                   'markeredgecolor','k','linewidth',3};

xxcopy = xx;
%%% following lines compute interpolating polynomials. The prediction curve is
%%% composed from segments of these polynomials
%%% As the polynomials are computed explicitly (not using
%%% interpolynomialprediction), the outcome shows no boundary effects
greycolor = [1 1 1]*0.4;
xe = knots;
k = kL;
uu = (0:nn)/nn; 
ye = zeros(size(xe)); ye(k) = 1;
for j=0:2,
   ne = length(xe);
   xo = (xe(1:ne-1)+xe(2:ne))/2;
   yo = zeros(size(xo));
   plot(xe,ye,evenopt{:})
   hold on
   xxx = []; yyy = [];
   for o = k-ptc*2^j:k+ptf*2^j,
      % xx = uu*xo(o-1)+(1-uu)*xo(o+1);
      xx = (1-uu)*xe(o-1)+uu*xe(o+2);
      yy = interpolationneville(xx,xe(o-ptf:o+ptc),ye(o-ptf:o+ptc));
        yy(xx<xe(o+1) & xx>xe(o)) = NaN; 
        % avoids overlap of grey and black dashed lines
      % plot(xx,yy,':','color',greycolor,'linewidth',4)
      plot(xx,yy,':','color','k','linewidth',4)
      xx = (1-uu)*xe(o)+uu*xe(o+1);
      yy = interpolationneville(xx,xe(o-ptf:o+ptc),ye(o-ptf:o+ptc));
      xxx = [xxx xx]; yyy = [yyy yy];
      % plot(xx,yy,':','color','k','linewidth',4) 
      xoo = xo(o);
      yoo = interpolationneville(xoo,xe(o-ptf:o+ptc),ye(o-ptf:o+ptc));
      yo(o) = yoo;
   end
   % plot(xxx,yyy,':','color','k','linewidth',4)
   plot(xxx,yyy,'-','color','k','linewidth',4)
   axy = [-0.1 1.1 -0.7 1.5];
   axis(axy)
   axis off
   drawaxes
   plot(xo,yo,oddopt{:})
   plot(xe,ye,evenopt{:})
   hold off
   if pauseon == true, pause, end
   k = 2*k-1;
   if makeeps==true, 
      makefigtransparent
      fname = ['DD4subdivisionstep' num2str(j+1)];
      print('-depsc',fname)
   else
      pausenr = pausenr+1;
      disp(['Press any key to continue (' num2str(pausenr) ')'])
      pause
   end
   [xe oe] = sort([xe; xo]);
   ye = [ye; yo];
   ye = ye(oe);
end

xx = xxcopy;
k = kL;
PhiDDk = PhiDD(:,k);
PhiDDnotk = PhiDD(:,[(1:k-1) (k+1:nL)]);
% next few lines to avoid interference of curves and arrows in plot
i = find(xx>1.05);
for l = 1:nL-1,
   philbeyond1 = PhiDDnotk(i,l);
   ll = find(abs(philbeyond1)<0.1);
   philbeyond1(ll) = NaN;
   PhiDDnotk(i,l) = philbeyond1;
end
plot(xx,PhiDDnotk,'linewidth',3,'color',greycolor)
hold on
plot(xx,PhiDDk,lineopt{:})
plot(knots,zeros(size(knots)),knotopt{:})
plot(knots,ones(size(knots)),knotopt{:})
plot(knots(nknots)*[1 1],[0 1],lineopt{:})
plot(knots([1 nknots]),[1 1],knotopt{:})
hold off
% axy = [-0.1 1.1 -1.2 1.8];
axis(axy)
axis off
drawaxes

if makeeps==true,
   makefigtransparent
   print -depsc DeslauriersDubuc4basisk.eps,
else
   pausenr = pausenr+1;
   disp(['Press any key to continue (' num2str(pausenr) ')'])
   pause
end

% number of knots is too low to avoid boundary effects in the polynomial
% prediction curve. Run with mirrorextension = true;
Px = interpolynomialprediction(knots,eye(nL),xx,ptilde);
plot(xx,Px(1:nn,k),lineopt{:})
hold on
plot(knots,zeros(nL),evenopt{:})
plot(knots(k),1,evenopt{:})
hold off
axy(3) = floor(10*min(Px(1:nn,k)))/10;
axis(axy)
axis off
drawaxes

if makeeps==true,
   makefigtransparent
   print -depsc DeslauriersDubuc4predictionfunction.eps,
else
   pausenr = pausenr+1;
   disp(['Press any key to continue (' num2str(pausenr) ')'])
   pause
end
knots = knots0; % remove extension used in the calculations
PhiDD = PhiDD(1:nn,nknots:2*nknots-1);
