
% 
% See also ../Chapters234/makefigDeslauriersDubuc.m
%          ../Chapters234/makefigBsplinesptilde.m 
%          ../Chapters234/makefigBsplines1234.m 

if exist('randomknots') ~= 1, randomknots = false; end
if exist('mirrorextension') ~= 1, mirrorextension = false; end
if exist('makeeps') ~= 1, makeeps = false; end
if exist('pauseon') ~= 1, pauseon = false; end

if exist('knotsasinbook') ~= 1, knotsasinbook = true; end
% In contrast to makefigDeslauriersDubuc and makefigBsplines, the number of
% refinement points (nn) in makefigMLPTbasis.m must be made dependent on the
% number of resolution levels.

%%%%%%%%%%%%%%%%%%% Parameters of MLPT refinement %%%%%%%%%%%%%%%%%%%%%%
if exist('ptmlpt') ~= 1, ptmlpt = 2; end
% bandwidth h0 has crucial impact on the shape of the basis functions. Check
% for instance h0 = 0.4; (Note that in the example in the help of
% refinescalingfunctionsMLPT, the number of knots is higher, so h0 here should
% be larger than there)
if exist('h0') ~= 1, h0 = 0.25; end
if exist('nreslevels') ~= 1, nreslevels = 3; end
% In wavelet refinement, the number of resolution levels is fixed by the number
% of knots at the finest scales, because wavelet refinement is dyadic.
% Since MLPT refinement is not necessarily dyadic, nreslevels is free to
% choose.
Pmethod = 'extlocpolestimation00';
M = nreslevels;
kerneltype = 'cos'; % help evalkernel for other options
hh = h0/2^M; 
MLPTpar = {M,'P',Pmethod,'kerneltype',kerneltype,'nt',ptmlpt,'bandwidth',hh,...
                'convex',true};
if exist('moreMLPTpar'), MLPTpar = {MLPTpar{:},moreMLPTpar{:}}; end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

knotopt = {'ko','markersize',12,'markerfacecolor','k'};
% i.e.:   {'o','markersize',12,'markeredgecolor','k','markerfacecolor','k'};
lineopt = {'linewidth',3,'color','k'};

if exist('knots'),
   knots = column(knots); nknots = length(knots);
elseif knotsasinbook==true,
   chooseknotsasinbook; knots = knots7;
   nknots = 7;
else
   if randomknots == false, rand('state',2), end
   if exist('nknots') ~= 1, nknots = 7; end
   knots = sort(rand(nknots,1));
   knots = (knots-knots(1))/(knots(nknots)-knots(1));
end
nL = nknots;

%%%%%%%%%%%%%%%%%%%%%%%% choose the refinement knots %%%%%%%%%%%%%%%%%%%%%%%
% if nreslevels grows, then so should the length of the fine resolution grid. 
% More precisely, if M<-M+1, then nn = length(xx)<-2*length(xx)-1
% (see help refinescalingfunctionsMLPT)
% nn(M) = 2*nn(M-1)-1 = ... = 2^M*nn0-(2^M-1) = 2^M*(nn0-1)+1

if exist('dyadicsubdivfromknots') ~= 1, dyadicsubdivfromknots = false; end
if dyadicsubdivfromknots==true,
   nn = 2^M*(nL-1)+1; xx = polyline((0:nn-1),(0:2^M:nn-1),knots);
end
if exist('xx') ~= 1, 
   nn0 = 126; nn = 2^M*(nn0-1)+1; xx = (0:nn-1)/(nn-1);
end


knotopt = {'ko','markersize',12,'markerfacecolor','k'};
% i.e.:   {'o','markersize',12,'markeredgecolor','k','markerfacecolor','k'};
lineopt = {'linewidth',3,'color','k'};

begincomments = true;
endcomments = false;
commentsline = '------------------------------------------------------------';
if makeeps == false,
   disp(commentsline)
   disp('This is routine makefigMLPTbasis speaking:')
   disp('No eps will be printed. Type makeeps = true; for eps outputs')
   begincomments = false;
   endcomments = true;
end
if mirrorextension == false,
   if begincomments == true, disp(commentsline), end
   disp('Boundary effects will be visible. Type mirrorextension = true')
   endcomments = true;
end
if endcomments == true, disp(commentsline), end

x = knots;
kL = max(3,2*ptmlpt); kL0 = kL;
if mirrorextension == true,
   x = [-x(nL:-1:2); x; 2-x(nL-1:-1:1)]; kL = kL+nL-1; nL = 3*nL-2;
   knots = x;
   a = -0.1; b = 1.1; xx = a+(b-a)*xx;
end
xxknots = sort(unique([column(xx); knots]));
kk = zeros(nknots,1);
for k=1:nknots,
   knotinxxknots = find(xxknots==knots(k)); kk(k) = knotinxxknots(end);
end


PhiMLPT = refinescalingfunctionsMLPT(xx,knots,MLPTpar{:});
PhiMLPTxxknots = refinescalingfunctionsMLPT(xxknots,knots,MLPTpar{:});

plot(xx,PhiMLPT,lineopt{:})
hold on
plot(knots,zeros(size(knots)),knotopt{:})
plot(knots,diag(PhiMLPTxxknots(kk,1:nknots)),knotopt{:})
plot(knots(nknots)*[1 1],[0 1],lineopt{:})
plot(knots([1 nknots]),[1 1],knotopt{:})
hold off
axy = [-0.1 1.1 -0.2 1.2]; axis(axy)
axis off

figsize = [1280 420]; papersize = figsize/96; figpaperpos = [0 0 papersize];
figpos = get(gcf,'position'); figpos(3:4) = figsize;
set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)

drawaxes
if makeeps==true,
   if exist('filename') ~= 1, filename = 'MLPTbasis.eps'; end
   makefigtransparent
   print('-depsc',filename);
end
