% Makes Figures 12.2, 12.3(a) and 12.4
% see illustrateconstraintoptYisXbeta.m

if exist('makeslides') ~= 1, makeslides = false; end
fontsize = 18;
fontweight = 'bold';
fontspec = {'fontsize',fontsize,'fontweight',fontweight};

for dosingular = [false true],
   illustrateconstraintoptYisXbeta

   figure(2)
   if dosingular == false,
      % add one circle

      % from the l1 penalised problem, we take the outmost ellips
      s = sqrt(SSEell1(l)-norm(Y-X*betaLS0)^2);
      % tt is parametrisation of unit circle; s is multiplication; R1 is
      % 2x2-matrix describing axes of ellips: betaLS = repamt(betaLS0)
      betas = betaLS+R1\(s*tt);

      % We have
      SSEs = s^2+norm(Y-X*betaLS0)^2;
      % We now need to solve for lambda:
      % SSEs = norm(Y-X*betaL2)^2 with betaL2 = (X'*X+lambda*I)\(X'*Y)
      % This has to be done in an interative way (see p.34.41)
      % Therefore, we chose an s closeby for which the solution is known
      l = min(find(SSEell2-norm(Y-X*betaLS0)^2 > s^2));
      s = sqrt(SSEell2(l)-norm(Y-X*betaLS0)^2)
      C = norm(betaL2(1:m,l));
      betas = betaLS+R1\(s*tt);
      hold on
      fill(C*l2ball(1,1:nn),C*l2ball(2,1:nn),fillcolor*0.8)
      plot(C*l2ball(1,1:nn),C*l2ball(2,1:nn),fullline{:})
      plot(betaL2(1,1:L),betaL2(2,1:L),dottedline{:})
      plot(betaL2(1,l),betaL2(2,l),bullet{:})
      plot(betas(1,1:nn),betas(2,1:nn),fullline{:})
      plot([-C C],[0 0],'linewidth',3,'color','k')
      plot([0 0],[-C C],'linewidth',3,'color','k')
      hold off
   end
   axy = axis;
   text(axy(2)*0.87+axy(1)*0.13,axy(4)*0.1,'\beta_1',fontspec{:})
   text(axy(2)*0.03,axy(4)*0.9+axy(3)*0.1,'\beta_2',fontspec{:})
   figure(1)
   text(axy(2)*0.87+axy(1)*0.13,axy(4)*0.1,'\beta_1',fontspec{:})
   text(axy(2)*0.03,axy(4)*0.9+axy(3)*0.1,'\beta_2',fontspec{:})

   bbias2 = zeros(L+1,1);
   vvar = zeros(L+1,1);
   for l = 1:length(ll),
     lambda = ll(l);
     Alambda = (XTX+lambda*I)\X';
     bias2 = norm(Alambda*mu-beta)^2/n;
     variance = stdev*trace(Alambda*Alambda')/n;
     bbias2(l) = bias2;
     vvar(l) = variance;
   end
   rrisk = bbias2+vvar;

   figure(3)
   plot(ll,rrisk,dottedline{:})
   axy = axis; axy(3) = 0; axis(axy); axis off; drawaxes
   text(axy(2)*0.97+axy(1)*0.03,axy(4)*0.05,'\lambda',fontspec{:})
   text(axy(2)*0.03,axy(4)*0.95+axy(3)*0.05,'R(\lambda)',fontspec{:})

   if makeeps == true,
      if makeslides == true, for i = 1:3,
         figure(i)
         makefigtransparent
      end, end
      if dosingular == true,
         figure(1); print -depsc l1regLSsing.eps
         figure(2); print -depsc l2regLSsing.eps
         figure(3); print -depsc l2regLSsingRisk.eps
      else
         figure(1); print -depsc l1regLS.eps
         figure(2); print -depsc l2regLS.eps
         figure(3); print -depsc l2regLSRisk.eps
      end
      if makeslides == true, close all; end
   elseif dosingular == false,
      disp('press any key to continue')
      pause
   end
end

% scp majansen@hydra.ulb.ac.be:/u/majansen/Matlab/Uitvoer/l*regLS*.eps .

