
% Makes Figure 10.4

if exist('realrandom') ~= 1, realrandom= false; end
if exist('BW') ~= 1, BW = true; end
if exist('makeeps') ~= 1, makeeps = false; end

edgeopt = {'k:','linewidth',2};
vertexopt = {'k.','MarkerSize',40};

if BW==true,
   % fullcolors = 0.3+(0:5)'/5*0.5*[1 1 1];
   fullcolors = 0.8-(5:-1:0)'/20*[1 1 1];
   extracolor = fullcolors(6,1:3)+0.05;
else
   % fullcolors = [0 0 1; 0 1 0; 0 1 1; 1 0 0; 1 0 1; 1 1 0];
   fullcolors = [0 0 1; 1 0.8 0.2; 0.4 1 0.3; 1 0 0; 1 0 1; 0 1 1];
   extracolor = [0.95 0.85 0.8];
end
close all
n = 180;
if realrandom == false, rand('state',2), end
x = rand(n,1); y = rand(n,1);
x0 = 1/2; y0 = 1/2;
x1 = [x; x0]; y1 = [y; y0];

vc = cell(n,1);
for v=1:n,
   vc{v} = constructvoronoicell(v,x,y);
end
vc1 = cell(n+1,1);
[vc1 vc1neighbours] = constructvoronoicell(n+1,x1,y1);

tri = bndrycstrdelaunay1(x,y);
tri1 = bndrycstrdelaunay1(x1,y1);
cellcolors = zeros(1,n);

figure(1)
for v = 1:n,
   vn = findneighbours(v,tri);
   neighborcolors = cellcolors(vn);
   cellcolors(v) = min(setdiff(1:6,neighborcolors));
   cc = fullcolors(cellcolors(v),1:3);
   fill(vc{v}(:,1),vc{v}(:,2),cc)
   hold on
end

neighborcolors = cellcolors(vc1neighbours);
nvc1n = length(vc1neighbours);
x0cell = [vc1(nvc1n,1); vc1(:,1)]; y0cell = [vc1(nvc1n,2); vc1(:,2)];
A = zeros(nvc1n,1);
L = zeros(nvc1n,1);
A0 = areapoints(x0cell,y0cell);
for m=1:nvc1n,
   cc = fullcolors(neighborcolors(m),1:3);
   % cc1 = hsv2rgb(rgb2hsv(cc).*[2 1 2]/2);
   if BW==false,
      cc1 = hsv2rgb(rgb2hsv(cc).*[3 1 3]/3);
   else
      % cc1 = cc+0.1;
      % cc1 = 1-(1-cc).^2;
      cc1 = extracolor-(extracolor-cc).^2;
   end
   xncell = vc{vc1neighbours(m)}(:,1); yncell = vc{vc1neighbours(m)}(:,2);
   i = find(pointsinside(xncell,yncell,1:nvc1n,x0cell,y0cell));
   xn = [xncell(i); x0cell(m:m+1)]; yn = [yncell(i); y0cell(m:m+1)];
   conv = convexhull2(1:length(xn),xn,yn);
   xn = xn(conv); yn = yn(conv);
   A(m) = areapoints(xn,yn);
   L(m) = sqrt((x0cell(m+1)-x0cell(m))^2+(y0cell(m+1)-y0cell(m))^2);
   fill(xn,yn,cc1)
end
D = sqrt((x0-x(vc1neighbours)).^2+(y0-y(vc1neighbours)).^2);
LD0 = sum(L./D);
% Natural neighbour interpolation
% (1) Sibson interpolation
predictionA = A'*[x(vc1neighbours) y(vc1neighbours)]/A0
% (2) Laplace interpolation
predictionD = (L./D)'*[x(vc1neighbours) y(vc1neighbours)]/LD0
x0yo = [x0 y0]

   
plotmesh(tri1,x1,y1,edgeopt{:})
plot(x,y,vertexopt{:})
if BW==false,
   plot(x0,y0,'r.','MarkerSize',40)
else
   plot(x0,y0,'k.','MarkerSize',45)
   plot(x0,y0,'.','color',[1 1 1]*254/255,'MarkerSize',30)
   plot(x0,y0,'k.','MarkerSize',20)
end
hold off
axis equal
axis off
axis([1,2,1,2]/3)

if makeeps==true,
   makefigtransparent
   if BW==true,
      print -depsc sibsonBW.eps
   else
      print -depsc sibson.eps
   end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
vc1 = cell(n+1,1);
for v=1:n+1,
   vc1{v} = constructvoronoicell(v,x1,y1);
end
cellcolors = [cellcolors 0];
figure(2)
neighborcolors = cellcolors(vc1neighbours);
lastcellcolor = setdiff(1:6,neighborcolors);
if isempty(lastcellcolor),
   % it is possible that the last cell cannot be given a color that is
   % different from all its neighbours, while at the same time, these
   % neighbours have different colors from all their neighbours after taking
   % away the last cell.
   cc = extracolor;
else
   cellcolors(n+1) = min(lastcellcolor);
   cc = fullcolors(cellcolors(n+1),1:3);
end
fill(vc1{n+1}(:,1),vc1{n+1}(:,2),cc)
hold on
for v = 1:n,
   cc = fullcolors(cellcolors(v),1:3);
   fill(vc1{v}(:,1),vc1{v}(:,2),cc)
end
plotmesh(tri1,x1,y1,edgeopt{:})
plot(x1,y1,vertexopt{:})
hold off
axis equal
axis off
axis([1,2,1,2]/3)

if makeeps==true,
   makefigtransparent
   if BW==true,
      print -depsc voronoiBW.eps
   else
      print -depsc voronoi.eps
   end
end

