% Makes Figure 8.2
% See also makefigBsplines1234.m and makefigBsplinesptilde.m
%
% This test illustrates that in a hierarchical B-spline basis, the null
% function can be decomposed in a non-trivial way.
%
% In order to prove this, we start from a low resolution function PhiL*sL
% and then search for details dL so that PhiL*sL+PsiL*dL = PhiLplus1*sLplus1
% has the lowest possible norm. After repeating this a couple of times, we see
% that the resulting fine resolution function converges to zero in L2.
% The low resolution function is plotted in blue, the high resolution function
% is plotted in red. The finest resolution can be raised by setting
% nlevels = nlevels+1; nontrivialexpansion0hierarchicalBsplinebasis
%
% Note that hierarchical B-spline bases DO require a final update, unless the
% number of dual vanishing moments is one or two (Haar of triangular hat)

if exist('makeepsfiles') ~= 1, makeepsfiles = false; end
if exist('makefigs') ~= 1, makefigs = true; end
if exist('randomknots') ~= 1, randomknots = false; end
if exist('dualmom') ~= 1, dualmom = 4; end
if exist('knotsasinbook') ~= 1, knotsasinbook = true; end
if exist('nn') ~= 1, nn = 1000; end
if exist('nlevels') ~= 1, nlevels = 5; end
if exist('fnames') ~= 1, fnames = 'apprx0hierarBspline'; end
if exist('figsize') ~= 1, figsize = [1280 420]; end
if exist('papersize') ~= 1, papersize = figsize/96; end
if exist('figpaperpos') ~= 1, figpaperpos = [0 0 papersize]; end


grey = 0.75*[1 1 1];
knotopt = {'o','markersize',12,'markeredgecolor','k','markerfacecolor','k'};
greyknotopt = knotopt;
greyknotopt{5} = grey; greyknotopt{7} = grey;
lineopt = {'linewidth',3,'color','k'};
greylineopt = {'linewidth',3,'color',grey};
ptilde = dualmom;

if exist('knots'),
   knots = column(knots); nknots = length(knots);
elseif knotsasinbook==true,
   chooseknotsasinbook; knots = knots7;
   nknots = 7;
else
   if randomknots == false, rand('state',2), end
   if exist('nknots') ~= 1, nknots = max(7,2*ptilde-1); end
   knots = sort(rand(nknots,1));
   knots = (knots-knots(1))/(knots(nknots)-knots(1));
end
nL = nknots;
xL = knots;
xx = (1:nn)/nn;
if randomknots==false, rand('state',0); randn('state',0); end

PhiBL = Bsplinebasis(xx,xL,ptilde,false);
sL = ones(nL,1);
L = 0; 
if makefigs == true,
   plot(xx,PhiBL,greylineopt{:})
   hold on
   plot(xx,PhiBL*sL,lineopt{:})
   plot(xL,zeros(size(xL)),knotopt{:})
   hold off
   axy = [0 1.1 -0.2 1.2]; axis(axy);
   figpos = get(gcf,'position'); figpos(3:4) = figsize;
   set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
   axis off
   drawaxes
   if makeepsfiles == true,
      fname = [fnames '0.eps'];
      makefigtransparent
      print('-deps',fname);
   else
      disp('This is level 0. Press any key to continue')
      pause
   end
end

M = nlevels; J = L+M;
nj = nL; xj = xL; sj = sL;
for j = L:J-1,
   no = nj-1; nf = nj+no;
   xo = randbeta(no,1,4);
   xo = (1-xo).*xj(1:no) + xo.*xj(2:nj);
   xf = zeros(nf,1); xf(1:2:nf) = xj; xf(2:2:nf) = xo;
   Hj = Bsplinerefinement(xf,ptilde,false);
   Gj = zeros(nf,no); Gj(2:2:nf,1:no) = eye(no);
   Af = grammatrixBsplines(xf,ptilde);
   pt = floor((ptilde-1)/2);
   Af = Af(pt+(1:nf),pt+(1:nf));
   Aoo = Af(2:2:nf,2:2:nf); Aoe = Af(2:2:nf,1:2:nf);
   dj = -(Aoo\Aoe)*sj;
   sj = Hj*sj+Gj*dj; nj = nf; xj = xf;

   if makefigs == true,
      PhiBj = Bsplinebasis(xx,xj,ptilde,false);
      plot(xj,zeros(size(xj)),knotopt{:})
      hold on
      plot(xo,zeros(size(xo)),greyknotopt{:})
      plot(xx,PhiBj(1:nn,2:2:nf),greylineopt{:})
      plot(xx,PhiBj*sj,lineopt{:})
      plot(xx,PhiBL*sL,':',lineopt{:})
      hold off
      axy = [0 1.1 -0.2 1.2]; axis(axy);
      figpos = get(gcf,'position'); figpos(3:4) = figsize;
      set(gcf,'position',figpos,'papersize',papersize,'paperposition',figpaperpos)
      axis off
      drawaxes
      if makeepsfiles == true,
         fname = [fnames num2str(j+1) '.eps'];
         makefigtransparent
         print('-deps',fname);
      else
         disp(['This is level ' num2str(j+1) '. Press any key to continue'])
         pause
      end
   end
end
if makefigs == false,
   disp('Set makefigs = true; to display figures')
end
if makeepsfiles == false,
   message1 = 'no eps files have been printed. Set makeepsfiles = true;';
   message2 = ' to print eps files.';
   disp([message1 message2])
end

