
function d = simpleCWT(x,y,psi,s);

% simpleCWT - A simple implementation of the Continuous Wavelet Transform
% Usage
%   d = simpleCWT(x,y,psi,s);
% Input
%   x    ordered real vector; covariate values (length n)
%   y    real vector; response values (length n)
%   psi  char/string; wavelet function (e.g. 'mexicanhat')
%   s    real vector; scales (length M)
% Output
%   d    M times n matrix of CWT coefficients
% See also
%   help mexicanhat
%   help derivgauss


if ischar(y),
   s = psi;
   psi = y;
   y = x;
   n = length(y);
   x = (0:n-1)/(n-1);
end
x = column(x); y = column(y); dx = initmom(x);
n = length(x); M = length(s); 
for j=1:M, for i=1:n,
   sj = s(j);
   d(j,i) = (y.*feval(psi,(x-x(i))/sj)/sqrt(sj))'*dx;
end, end

