
function beta = planefrompoints(varargin);

% planefrompoints -- find plane with smallest mean squared distance to points
%  Usage
%    beta = planefrompoints(x);
%    beta = planefrompoints(x1,x2,x3,...)
% Inputs
%    x            real matrix defining the points (columns of x)
%    x1,x2,x3,... real vectors of equal length 
% Outputs
%    beta         real vector of length n+1 (with n=length(x1))
% Description
%    finds beta, such that beta(1:n)'*x+beta(n+1) defined the least squares 
%    plane w.r.t. the points x1,x2,x3,...
% Note
%
% See Also
%          

if nargin==1,
   x = varargin{1};
else 
   m = length(varargin); n = length(varargin{1}); x = zeros(n,m);
   for k=1:m, x(1:n,k) = column(varargin{k}); end
end

x0 = mean(x')';  
[n m] = size(x); if n~=3, x = x'; m = n; end
if m==n-1, x = [x zeros(n,1)]; m = n; end

A = [x' ones(m,1)];
% solve the system A*beta = 0, i.e., find beta with norm(beta)=1 and
% norm(A*beta) as small as possible
[U S V] = svd(A);
% It holds USV' = A; with U and V orthogonal matrices
% Let gamma = V'*beta, then norm(gamma) = norm(beta) and
% norm(A*beta) = norm(USV'*beta) = norm(S*gamma)
% We look for norm(gamma)=1 and norm(S*gamma) as small as possible.
% Since the elements of diag(S) are in descending order, gamma = [0 0... 1]'
beta = V*[zeros(n,1);1];
