function [x Df it] = zerossincosx2xvec(a,b,c,d,maxit,tol,iterateallrows);

% zerossincosx2xvec -- finds zeros of
%                      f(x) = a*sin(2x)+b*cos(2x)+c*sin(x)+d*cos(x) on [0 2*pi]
%  Usage
%    [x Df it] = zerossincosx2xvec(a,b,c,d,maxit,tol);
%  Inputs
%    a,b,c,d      scalars or equally sized vectors
%    maxit        maximum number of iterations
%    tol          tolerance for use in numerical equality
%    iterateallrows boolean: true means that all rows are iterated as long as
%                            one row does not meet the stopping criterion
%  Outputs
%    x            r x 9 matrix with r=length(a)=length(b)=length(c)=length(d)
%    Df           f'(x) 
%    it           integer value: number of iterations used
%  Description
%  Note
%  See also

if nargin<7, iterateallrows = false; end
if nargin<6, tol = 1.e-10; end
if nargin<5, maxit = 1000; end
r = length(a);
n = 9;
a = column(a)*ones(1,n); b = column(b)*ones(1,n); c = column(c)*ones(1,n); 
d = column(d)*ones(1,n);
x = zeros(1,n);
xnew = (0:n-1)/n*2*pi;
x = ones(r,1)*x;
xnew = ones(r,1)*xnew;

it = 0;
f = zeros(size(x));
out = []; 
j = (1:r);
while length(j)>0,
   if iterateallrows==true, j = (1:r); end
   it = it+1;
   x = xnew;
   xj = x(j,1:n); aj = a(j,1:n); bj = b(j,1:n); cj = c(j,1:n); dj = d(j,1:n);
   fj = aj.*sin(2*xj)+bj.*cos(2*xj)+cj.*sin(xj)+dj.*cos(xj);
   Dfj = 2*aj.*cos(2*xj)-2*bj.*sin(2*xj)+cj.*cos(xj)-dj.*sin(xj);
   xjnew = xj - fj./Dfj;
   xnew(j,1:1:n) = xjnew;
   xnew(out) = 100;
   out = find(abs(xnew-pi)>pi*1.2);
   x(out) = 100; xnew(out) = 100;
   j = find(sum((x-xnew).^2,2)>tol | sum(f.^2,2) > tol);
   % if it>maxit, x = xnew;  f = 0; end
   if it>maxit, j = []; end
end
x = xnew;
% ignore all points outside [0, 2*pi]:
out = find(abs(x-pi)>pi);
x(out) = NaN;
x = sort(x,2);
% exclude all duplicates (up to tol)
x1 = [-ones(r,1) x];
nx = size(x,2);
[i j] = find(x1(1:r,2:nx+1)-x1(1:r,1:nx)<tol);
x(r*(j-1)+i) = NaN;
% exclude all points that did not converge (when it>maxit)
f = a.*sin(2*x)+b.*cos(2*x)+c.*sin(x)+d.*cos(x);
i = find(abs(f)>tol);
x(i) = NaN;
x = sort(x,2);
% if no value has been found on a given row, then let x be zero 
i = find(isnan(x(1:r,1)));
x(i,1) = 0;
Df = 2*a.*cos(2*x)-2*b.*sin(2*x)+c.*cos(x)-d.*sin(x);
