
function void = plotvector(a,b,varargin);

% plotvector -- plots 2D or 3D vectors
% Usage
%    plotvector(a,b,<options>)
% Inputs
%    a,b     real matrices, of size 3 x n, 2 x n, n x 3, n x 2
%    'arrowlength',arrowlength
%    'arrowwidth',arrowwidth
%    'arrowsize',arrowsize
%    <plot options> as in the command plot
% Outputs
%    void
% Description
%    plots in 2D or 3D the vectors ab
% Note
%
% See Also
%          


notinlegend = {'HandleVisibility','off'};
arrowlength = 0.07;
arrowwidth = 0.02;
linecolor = 'k';
plotoptions = {};
if nargin<2, b = a; a = zeros(size(b)); end
if ~isnumeric(b), varargin = {b,varargin{:}}; b = a; a = zeros(size(b)); end
if ~ismember(size(a,1),[2 3]), a = a'; end
n = size(a,1); 
if ~ismember(n,[2 3]), 
   error('plotvector works only in dimensions 2 or 3')
end
if size(b,1) ~= n, b = b'; end
if size(b,1) ~= n,
   error('plotvector dimension mismatch')
end
k = 1; nvarargin = length(varargin);
while k <= nvarargin, vark = varargin{k}; if ischar(vark), switch(vark)
   case {'arrowlength'},
      arrowlength = varargin{k+1};
      k = k+2;
   case {'arrowwidth'},
      arrowwidth  = varargin{k+1};
      k = k+2;
   case {'arrowsize'},
      arrowlength = varargin{k+1};
      arrowwidth  = 2/7*arrowlength;
      k = k+2;
   case {'color','linecolor'}
      linecolor = varargin{k+1};
      k = k+2;
   case {'b','g','r','c','m','y','k','w'},
      linecolor = vark;
      k = k+1;
   otherwise
      plotoptions = {plotoptions{:},vark};
      k = k+1;
   end
   else % if ischar(vark)
      plotoptions = {plotoptions{:},vark};
      k = k+1;
end, end
plotoptions = {plotoptions{:},'color',linecolor};
holdon = ishold;
m = size(b,2);
if size(a,2)==1, a = a*ones(1,m); end
L = arrowlength; W = arrowwidth; R = eye(n); R(1:2,1:2) = [0 -1;1 0]; 
if n==3 & m>1,
   % find a rotation matrix in the plane defined by the vectors in ab
   % (1) find the rotation axis, defining the least squares plane through the
   % points in a and b
   beta = planefrompoints([a b]); beta = beta(1:n); 
   % (2) Use Rodrigues' rotation formula
   % R = I+sin(theta)*K+(1-cos(theta))*K^2, where in this case theta = pi/2;
   I = eye(n); K = zeros(n,n); K(1,2:3) = [-beta(3) beta(2)];
   K(2,[1 3]) = [beta(3) -beta(1)]; K(3,1:2) = [-beta(2) beta(1)];
   R = I+K+K^2;
end

for v = 1:m,
   ab = b(1:n,v)-a(1:n,v); ab = ab/norm(ab);
   c = b(1:n,v)-L*ab; % c-a = alfa*(b-a); with alfa=1-L/norm(b-a)
                      % c is the point where the basis of the arrow
                      % intersects with the line ab
   arrow =  zeros(n,4); arrow(1:n,1) = b(1:n,v); arrow(1:n,4) = b(1:n,v);
   arrow(1:n,2:3) = c*[1 1]+W*R*ab*[1 -1];
   if size(a,1)>2,
      plot3([a(1,v) c(1)],[a(2,v) c(2)],[a(3,v) c(3)],plotoptions{:})
      % plot the part of the vector ab from a up to the arrow
      hold on
      fill3(arrow(1,1:4),arrow(2,1:4),arrow(3,1:4),linecolor)
      plot3(arrow(1,1:4),arrow(2,1:4),arrow(3,1:4),'color',linecolor)
   else
      plot([a(1,v) c(1)],[a(2,v) c(2)],plotoptions{:})
      hold on
      fill(arrow(1,1:4),arrow(2,1:4),linecolor)
      plot(arrow(1,1:4),arrow(2,1:4),'color',linecolor)
   end
end
if ~holdon, hold off, end
