
function f = derivativebumpjumpkink(x);

% ThreshLab/Tests/derivativebumpjumpkink -- creates derivative of bumpjumpkink 
%                     testfunction
%  Usage
%    f = derivativebumpjumpkink(x);
%    f = derivativebumpjumpkink(N);
%  Inputs
%    x      abscis value (possibly (non-)equidistant)
%    N      number of equidistant abscis values (1:N)/N
%  Outputs
%    f      function values of bumpjumpkink testfunction in x or (1:N)/N
%  Description
%    evaluates bumps testfunction in t = (x - x(1))/(x(N)-x(1))
%  See also
%    help blocks
%    help doppler
%    help heavisine
%    help skyline
%    help bumpjumpkink
%    help integralbumpjumpkink

N = length(x);
if N == 1 & x(1)>1,
   N = x;
   x = (1:N);
end
if N>1,
   t = (x - x(1))/(x(N) - x(1));
elseif 0<=x & x<= 1,
   t = x;
end

c = [0 0.3 0.4 0.62 0.7 0.85 Inf];
I = length(c)-1;
i = cell(I,1);

for k = 1:I,
   i{k} = find(t>=c(k) &  t<c(k+1));
end

f = zeros(size(t));
f(i{1}) = 9*cos(9*t(i{1}));
f(i{2}) = 0;
t3 = t(i{3}); n3 = length(t3); 
if n3>0,
   t0 = c(3); t1 = c(4); f(i{3}) = 8*(t3-t1)/(t0-t1)^2;
end
t4 = t(i{4}); n4 = length(t4); 
if n4>0,
   t0 = c(4); t1 = c(5); r = t1-t0; t4 = t4-t0;
   f4 = 8*t4/r^2./sqrt(1-t4.^2/r^2);
   f4(isnan(f4)) = 0;
   f4(isinf(f4)) = 0;
   f(i{4}) = f4;
end
t5 = t(i{5}); n5 = length(t5);
if n5>0, 
   t0 = c(5); t1 = c(6); r = t1-t0; t5 = t1-t5;
   f5 = -8*t5/r^2./sqrt(1-t5.^2/r^2);
   f5(isnan(f5)) = 0;
   f5(isinf(f5)) = 0;
   f(i{5}) = f5;
end
t6 = t(i{6}); n6 = length(t6);
if n6>0,
   t6 = t6-t6(1); f(i{6}) = 9;
end
