
% This routine is not a matlab function, because this way, we have easy access
% to all intermediate results/plots/etc.
%
% required input: 
%   y   observations (as a row vector)
%   pdfy string: 'Poisson' or 'normal'
%   L   coarsest resolution level of search
%      L = J-M = log2(N)-M with M the number of dyadic scales in continuous WT
%                         The lower the intensity, the lower the coarsest scale
%                         should be, as this coarsest scale needs sufficient
%                         binned observations to start the analysis from
%   m   number of intermediate scales in discretization of continuous WT
if exist('fontopt')~=1, fontopt={'fontsize',14,'fontweight','bold'}; end

N = length(y);
J = ceil(log2(N));
if exist('takebreaks') ~= 1, takebreaks = false; end
if exist('zthr') ~= 1, zthr = 3; end

if exist('pdfy') ~= 1, pdfy = 'normal'; end
if exist('L') ~= 1, L = 3; end
M = J-L;
if exist('m') ~= 1, 
   r = M-2;
   m = 2^(r+1)-r-2;
end

% Apply Continuous Haar-Fisz transform
switch pdfy
case {'normal','norm','Normal','Norm','Gaussian','Gauss'},
   z = CHT(y,M,m);
case {'pois','poisson','Poisson'},
   z = CHFT(y,M,m);
end

disp('The total number of resolution levels (dyadic + intermediate):')
Mm = size(z,1)
% This number of scales determines precision of the procedure.


% next line shifts wavelet coefficients such that they correspond to 
% centralised wavelet functions
z = shiftCWT(z,M,m);

disp('Find local maxima of wavelet transform')
hhthh = makelinearwaveletfilter('coiflet',4,6);
% hhthh is a filter, used to eliminate very local maxima due to noise
maxim = findCWTmaxima(z,hhthh);
if takebreaks==true, disp('press enter (1)'), pause, end

disp('Eliminate maxima that are closer to each other than the resolution of')
disp('the coefficients')
maxim = removeclosemaxima(maxim,z,M,m);
if takebreaks==true, disp('press enter (2)'), pause, end

disp('Connect maxima at successive scales')
maxlines = connectmaxlines(maxim);
maxlines0 = maxlines;
disp('maxima at successive scales now connected')
if takebreaks==true, 
   plotmaxlines(maxlines,'r')
   axis([0,N,0,Mm])
   yvalues = bestticks(Mm); D = Mm-max(yvalues);
   yticks = {'Ytick',yvalues+D,'YtickLabel',Mm-yvalues-D};
   set(gca,yticks{:},fontopt{:})

   disp('press enter (3)'), pause
end

disp('eliminate maxima lines without really large maximum')
maxllines = removelowmaxlines(maxlines0,z,zthr);
if takebreaks==true, 
   plotmaxlines(maxllines,'m')
   axis([0,N,0,Mm])
   set(gca,yticks{:},fontopt{:})

   disp('press enter (4)'), pause
end

disp('Remove unrealistic connections')
maxlllines = deconnectmaxlines(maxllines);
if takebreaks==true, 
   plotmaxlines(maxlllines,'b')
   axis([0,N,0,Mm])
   set(gca,yticks{:},fontopt{:})

   disp('press enter (5)'), pause
end

disp('Re-merge lines at overlapping locations')
maxlines = mergemaxlines(maxlllines);
if takebreaks==true,
   plotmaxlines(maxlines,'k')
   axis([0,N,0,Mm])
   set(gca,yticks{:},fontopt{:})

   disp('press enter (6)'), pause
end

disp('Select optimal unbalanced basis functions')
optimalunbalanced = findallunbalancedhaar(z,M,maxlines,y,pdfy);

addchangepointsaic

