
function dd = bandliftingstep(xe,xo,n);

% bandliftingstep - ThreshLab2/Irregular/1D/ --- band structure of lifting step
%   Usage
%      dd = bandliftingstep(xe,xo,n);
%   Inputs
%      xe   x coordinates of coarse scale points in current lifting step
%      xo   x coordinates of refinement points in current lifting step
%      n    number of free parameters (nonzero rows in each column of lifting
%           step)
%   Outputs
%      dd   integer matrix of size n x No (No = length(xo))
%   Description
%      finds nonzero rows for each column of U or P'
%      rows outside (1:Ne) are marked 0 or Ne+1 (Ne = length(xe))
%   See also
%      help FMLPT1D
%      help updateprimalmoments

No = length(xo); Ne = length(xe);
L = ceil(n/2); R = n-L;
% if n is odd, then one more even on the left is involved in the (update)
% lifting step then on the right (cfr. interpolynomialprediction)

dd = zeros(n,No);

for o = 1:No,
   xoo = xo(o);
   eo = max(find(xe<=xoo));
   if ~isempty(eo),
      eo = column(eo-L+1:eo+R); 
      dd(1:n,o) = eo;
   end
end
dd(find(dd>Ne)) = Ne+1;
dd(find(dd<1)) = 0;
