
function l = closestleftinvector(x,y,strict);

% closestleftinvector - ThreshLab2/Irregular/1D/ --- index manipulation
%   Usage
%      ii = closestleftinvector(x,y,strict)
%   Inputs
%      x      real vector
%      y      ordered real vector
%      strict boolean/logical variable (default false)
%   Outputs
%      l      integer vector of length=length(x) with indices into y
%             y(l(j)) is largest point in y smaller than (or equal to, if
%             boolean strict is false) x(j)
%             l(j) = 0 if no point in y is below x(j)
%   Note
%      This function is used in interpolynomialprediction and in
%      averinterpolynomialprediction.m
%   See also
%      help interpolynomialprediction
%      help averinterpolynomialprediction

if nargin<3, strict = false; end
if ischar(strict), 
   if ismember(strict,{'strict','Strict'}),
      strict = true;
   else,
      strict = false;
   end
end
nx = length(x);
ny = length(y);
[y o] = sort(y);
l = ny*ones(1,nx);
if strict, % basing the calculations on complementary arguments, the option
           % strict involves inclusive inequalities
   for i = 1:ny, l(x <= y(i)) = l(x <= y(i))-1; end
else,
   for i = 1:ny, l(x <y(i)) = l(x < y(i))-1; end
end
i = find(l>0); l(i) = o(l(i));
