function UPt = duallifting(UP);

% duallifting - ThreshLab2/Irregular/1D/ --- 
%          finds dual lifting steps for use in refinementfromliftingsteps
% Usage
%   UPt = duallifting(UP);
% Input
%   UP      cell array of matrices
%   'addPD'
%   'addD'
% Output
%   UPt   cell array of matrices
% Note
%   refinementfromliftingsteps assumes the rightmost lifting step is a rescale
%   and the second from the right is a prediction. After taking transposes, the
%   second from the right will be an update. Therefore, this routine inserts a
%   null prediction between the newly formed update and the inverse rescaling
%
% See also
%   help liftingstepsBspline
%   help refinementfromliftingsteps

nUP = length(UP)-1;
D = UP{nUP+1};
P = UP{nUP};
[no, ne] = size(P);
n = ne+no;

UPt = cell(nUP+2,1);
for s = 1:nUP-1, UPt{s} = UP{s}'; end
% note that the inv([I 0;P I]) = [I -P;0 I]
% the minus-sign is not written here, because the inverse of a prediction
% becomes an update, and for updates, the minus-sign is already included in the
% implementation of refinementfromliftingsteps.m The same holds for
% inv([I U;0 I]) = [I 0;-U I]
UPt{nUP} = D\P';
UPt{nUP+1} = zeros(no,ne);
UPt{nUP+2} = diag(1./diag(D));
