% illustratevarianceprojection -- test routine: illustrates the variance of the
% projection P_L = W*D_L*Wtilde, where 
% typical testcase:
% gridnumber = 0; transforms = 1;
% or
% gridnumber = 0; transforms = 1; nlevels = 1; samplesize = 130;
% See also: illustrate_updateLSapprxprimmom
 

forestgreen = [34 139 34]/255;
purple = [128 0 128]/255;
if exist('gridnumber') ~= 1, gridnumber = 1; end
if exist('randomgrid') ~= 1, randomgrid = false; end
if exist('reallyrandomsamples') ~= 1, reallyrandomsamples = false; end
if exist('dualvanishingmoments') ~= 1, dualvanishingmoments = 4; end
if exist('nlevels') ~= 1, nlevels = 5; end
if exist('fontsize') ~= 1, fontsize = 14; end
if exist('transforms') ~= 1, transforms = (1:2); end
if exist('primalvanishingmoments') ~= 1, primalvanishingmoments = 2; end
if exist('dosvd') ~= 1, dosvd = false; end
if exist('nsamples') ~= 1, nsamples = 5; end
if exist('samplesize') ~= 1, samplesize = 1000; end
if exist('plotcoefwithbasis') ~= 1, plotcoefwithbasis = false; end
if exist('usecolors') ~= 1, usecolors = false; end
% if plotcoefwithbasis == true, then the output shown is F*coef, where
% F = basisfunctions evaluated in the knots (x), otherwise the output is simply
% coef.

if usecolors == false,
   color1 = [1 1 1]*0.7; color2 = 'k'; color3 = 'k';
   lw1 = 1; lw2 = 1; lw3 = 4;
   lt3 = '--'; % used in jansen16noneqBsplinewavelets
   lt3 = ':';
else
   color1 = 'b'; color2 = purple; color3 = 'r';
   lw1 = 1; lw2 = 3; lw3 = 3;
   lt3 = '-';
end

if reallyrandomsamples == false, 
   initstate = 0;
else
   initstate = randn('state');
end
transforms = max(1,min(2,transforms));

n = samplesize;
I = sparse(eye(n));
dualmom = dualvanishingmoments;
primmom = primalvanishingmoments;
x = makegrid(n,gridnumber,randomgrid)';
M = nlevels;

%%%%%%%%%%%%%%%%%%%%%%%%% 1. B-spline wavelets %%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%% 2. Deslauriers-Dubuc wavelets %%%%%%%%%%%%%%%%%%%%%%

titlefigs = {'Multiscale B-Splines','Deslauriers-Dubuc'};
for transform=transforms,
   randn('state',initstate); 
   if transform==1,
      [Wt, nL] = FWT2G1D(x,I,'Bspline',dualmom,primmom,M);
      W = IWT2G1D(x,I,'Bspline',dualmom,primmom,M);
      F = Bsplinebasis(x,x,dualmom);
   else
      [Wt, nL] = FWT2G1D(x,I,'DD',dualmom,primmom,M);
      W = IWT2G1D(x,I,'DD',dualmom,primmom,M);
      F = eye(n);
   end
   Sigmay = I;
   VL = W(1:n,1:nL);
   VtL = Wt(1:nL,1:n);
   VtLSs = (VL'*VL)\VL';
   Sigmaw = Wt*Sigmay*Wt';
   stdevw = sqrt(diag(Sigmaw));
   PL = VL*VtL;
   if dosvd == true,
      [U, S, V] =  svd(PL);
      % Note that VtL*VL = I !!
      sigma(transform,1:n) = diag(S);
   end


   errr = zeros(n,nsamples);
   errrVM = zeros(n,nsamples);
   errrLS = zeros(n,nsamples);
   figure(transform)
   for sample = 1:nsamples,
      sample
      err = randn(n,1);

      if transform==1,
         eta = FWT2G1D(x,err,'Bspline',dualmom,primmom,M);
      else
         eta = FWT2G1D(x,err,'DD',dualmom,primmom,M);
      end
      etaVM = eta; etaVM(nL+1:n) = 0;

      etaLS = column(etaVM);
      etaLS(1:nL) = VtLSs*err;

      if transform==1,
         errVM = IWT2G1D(x,etaVM,'Bspline',dualmom,primmom,M);
         errLS = IWT2G1D(x,etaLS,'Bspline',dualmom,primmom,M);
      else
         errVM = IWT2G1D(x,etaVM,'DD',dualmom,primmom,M);
         errLS = IWT2G1D(x,etaLS,'DD',dualmom,primmom,M);
      end
      % next line investigates behavior for a synthesis that is the
      % pseudo-inverse of the analysis (instead of vice versa)
      errLSdual = VtL'*((VtL*VtL')\etaVM(1:nL));
      if plotcoefwithbasis == true,
         errVM = F*errVM; errLS = F*errLS; err = F*err;
      end

      errr(1:n,sample) = err;
      errrVM(1:n,sample) = errVM;
      errrLS(1:n,sample) = errLS;
      errrLSdual(1:n,sample) = errLSdual;
   end
   for sample = 1:nsamples,
      plot(x,errr(1:n,sample),'linewidth',lw1,'color',color1)
      hold on
   end
   for sample = 1:nsamples,
      plot(x,errrVM(1:n,sample),'linewidth',lw2,'color',color2)
   end
   for sample = 1:1,
      plot(x,errrLS(1:n,sample),lt3,'linewidth',lw3,'color',color3)
   end
   hold off
   if gridnumber == 0,
      titlefig = [titlefigs{transform} ', equidistant'];
   else
      titlefig = [titlefigs{transform} ', non-equidistant'];
   end
   title(titlefig,'fontsize',18,'fontweight','b')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1)
if exist('axy') ~= 1, axy = axis; axy(2) = 1.1; end
axis(axy)
axis off
drawaxes

figure(2)
axis(axy)
axis off
drawaxes
figure(1)

if dosvd==true,
   if exist('figsize') ~= 1, figsize = [840 420]; end
   if exist('figpaperpos') ~= 1, figpaperpos = [0 0 figsize/96]; end
   plotspecs = {'linewidth',2,'markerfacecolor','w','markersize',7};
   plotsopt = {'ko-','kd-','k^-','kv-','ks-'};
   bf = {'fontsize',fontsize,'fontweight','bold'};
   bfit = {bf{:},'fontangle','italic'};
   nL150 = ceil(3*nL/2);
   figure(3)
   clf
   axs = [0 0 0 0];
   % axs(4) = floor(max(10,max(sigma(:,1))));
   axs(4) = 12;
   axs(2) = nL150 +5;
   axs(4) = axs(4)+1;
   axs(3) = -axs(4)/15;
   axis(axs)
   sticks = bestticks(0,axs(4),10);
   nticks = nL;
   ntickslabel = {'n_L'};
   drawopt = {'xticks',nticks,'xticklabel',ntickslabel,'yticks',sticks};
   figpos = get(gcf,'position'); figpos(3:4) = figsize;
   set(gcf,'position',figpos,'paperposition',figpaperpos)
   drawaxes(drawopt{:},bf{:})
   hold on
   for transform=transforms,
      plot(sigma(transform,1:nL150),plotsopt{transform},plotspecs{:});
   end
   hold off
   axis off
   legend(titlefigs{:},bf{:})
   title('SVD projections',bf{:})
end
