
function [H G Ht Gt UP] = mirrorfilt2G(H,nu,Mf,varargin)

% mirrorfilt2G - ThreshLab/ThreshLab2/Irregular/1D -- finds detail and dual
%                                   matrices for given refinement matrix
% Usage
%    [H G Ht Gt UP] = mirrorfilt2G(H,nu,Mf);
%    [H G UP] = mirrorfilt2G(H,nu,Mf);
%    [H G] = mirrorfilt2G(H,nu,Mf);
%    [H G ...] = mirrorfilt2G(H,Mf);
%    G = mirrorfilt2G(H,Mf);
% Inputs
%    H      refinement matrix, size nf x ne
%    nu     (default 0) integer or integer vector with degrees of freedom as in
%                                             FWT2G1D (parameter n)
%    Mf     nf x p matrix containing fine scale moments
% Outputs
%    H      same as input
%    G      primal detail matrix
%    Ht     dual refinement matrix
%    Gt     dual detail matrix
%    UP     lifting scheme (cell of lifting matrices)
% See also
%    help FWT2G1D
%    help liftingstepsfromrefinement
%    help mirrorshifts  (the first generation version of mirrorfilt2G)

[nf ne] = size(H); no = nf-ne;
UP = liftingstepsfromrefinement(H);

if nargin<2, nu = 0; end
if nargin<3, Mf = NaN; end
if max(size(nu))==nf, Mfcopy = Mf; Mf = nu; nu = Mfcopy; end 
if max(size(nu))>2 | min(size(nu))>1, error('incorrect parameter nu'), end
if isnan(nu), nu = min(size(Mf)); end
p = nu(1);
if isnan(Mf) & p>0, Mf = initmom(1:nf,(0:p-1)); end
if ~isnan(Mf),
   if size(Mf,1)~=nf, Mf = Mf'; end
   if size(Mf,1)~=nf, error('size Mf incompatible with size H'); end
end

nu = sum(nu)-p;

[Hbis G0] = refinementfromliftingsteps(UP);
Me = H'*Mf;
Mo = G0'*Mf;
% FINAL UPDATE (for wavelet functions) %
U = zeros(ne,no);
if p>0 & nu==0 % all free parameters for VANISHING MOMENTS
   U = updateprimalmoments(Mo,Me);
end
if nu>0, % make transform as close as possible to ortho
   [U, W, Wt] = updateLSapprxprimmom(UP,nu,Me,Mo,varargin{:});
end
G = G0-H*U;

if nargout>3,
   UPt = duallifting(UP);
   [Ht0 Gt] = refinementfromliftingsteps(UPt);
   Ht = Ht0+Gt*U'; % exercise 4.1.1
elseif nargout == 3,
   Ht = UP;
elseif nargout==1,
   H = G;
end
