function UP = nondecimatedliftingsteps(liftingmethod,x,varargin)

% nondecimatedliftingsteps - ThreshLab2/Irregular/1D/ --- 
%        finds nonecimated lifting matrices in two-scale equation for B-splines
% Usage
%   UP = nondecimatedliftingsteps(liftingmethod,x,par2,'shift',shift)
% Input
%   liftingmethod   string, containing name of lifting routine
%   x               grid of locations; must be first parameter of liftingmethod
%   par2,par3,...   other parameters of liftingmethod
%   shift           boolean variable: shift=0 means that liftingmethod is
%                   carried out; shift=1 means that liftingmethod is carried
%                   out on shifted grid (for use in nondecimated transform)
% Output
%   UP    cell array of matrices
% Description
%   The default value for shift is 0 (or false)
%   When the routine is called with string 'shift', but without subsequent
%   boolean value, then the boolean is supposed to be true (or 1)
% See also
%   help liftingstepsBspline.m

s = false;
nvarargin = length(varargin);
arginliftingmethod = {x};
k = 1;
while k<nvarargin, 
   if ischar(varargin{k}),
      varname = varargin{k};
      switch varname,
      case {'shift'}
         s = true;
         if k<nvarargin,
            if islogical(varargin{k+1}),
               s = varargin{k+1}; k = k+1;
            elseif isnumeric(varargin{k+1}), 
               if ismember(varargin{k+1},[0 1]),
                  s = varargin{k+1}; k = k+1;
               end
            end
         end
      otherwise
         arginliftingmethod = {arginliftingmethod{:},varargin{k}};
      end
   else
      arginliftingmethod = {arginliftingmethod{:},varargin{k}};
   end
   k=k+1;
end

if s==false,
   UP = feval(liftingmethod,arginliftingmethod{:});
else
   [r, c] = size(x); if r>1, x = x'; end, x = [x(1) x]; if r>1, x = x'; end
   arginliftingmethod{1} = x;
   UP = feval(liftingmethod,arginliftingmethod{:});

   % following code assumes that last lifting step is rescaling, one but last
   % is prediction. If this is not known, then try to find out what is
   % prediction by looking at dimensions of UP{:} for x and for x extended. In
   % at least one of the cases, #evens = #odds+1
   nUP = length(UP)-1;
   D = UP{nUP+1};
   P = UP{nUP};
   [no, ne] = size(P); ne = ne-1;
   UP{nUP+1} = D(2:ne+1,2:ne+1);
   thisstepisprediction = nUP-2*floor(nUP/2);
   for s = 1:nUP,
      if thisstepisprediction == 1,
         P = UP{s};
         UP{s} = P(1:no,2:ne+1);
         thisstepisprediction = 0;
      else
         U = UP{s};
         UP{s} = U(2:ne+1,1:no);
         thisstepisprediction = 1;
      end
   end
end
