
function [even, odd] = split1off(x,varargin)

%  split1off -- partitions data for one coefficient-at-a-time prediction
%   Usage
%     [even, odd] = split1off(x);
%     [even, odd] = split1off(N);
%     [even, odd] = split1off(x,h);
%   Inputs
%     x      data vector, grid location vector, ...
%     N      length of (undisclosed) data vector
%     h      scale (bandwidth) parameter (optional)
%   Outputs
%     even   (1:N) minus odd
%     odd    singleton containing index of coefficient to be predicted
%   Description
%     [even, odd] = split1off(x) takes off the point x(i) with smallest values
%                                x(i+1)-x(i-1)
%     [even, odd] = split1off(x,h) takes off the point with most neighbours
%                                within distance h (and with smallest distance
%                                between furthest points within distance h in
%                                case of a draw)
%   Note
%   See also
%     help FWT2G1D

x = row(x);
N = length(x);
if N == 1, N = x; end

h = NaN;
middleknots = true;

nvarargin = length(varargin);
k = 0;
while k < nvarargin, k=k+1; vark = varargin{k}; 
   if ischar(vark), switch(vark)
      case {'UH'},
         middleknots = false;
      end
   elseif isnan(h), h = vark;
   end
end

if isnan(h),
   if middleknots == true,
      I = initmom(x); I([1 N]) = I([1 N])*2;
   else
      x0 = 0;
      I = x-[x0 x(1:N-1)];
   end
   [minI odd] = min(I);
else
   h = varargin{1};
   if isnumeric(h),
      r = zeros(size(x)); xs = frwshift(x);
      dr = (xs<x+h); dr(N) = 0; s=1; r=r+dr;
      while any(dr) > 0,
         s=s+1;
         xs = frwshift(x,s);
         dr = (xs<x+h); dr(N-s+1:N)=0; r=r+dr;
      end
      l = zeros(size(x)); xs = frwshift(x,-1);
      dl = (xs>x-h); dr(N) = 0; s=1; r=r+dr;
      while any(dr) > 0,
         s=s+1;
         xs = frwshift(x,-s);
         dr = (xs>x-h); dr(1:s)=0; l=l+dl;
      end
      rs = r+s+1;
      maxrs = max(rs);
      o = find(rs==maxrs);
      d = x((1:N)+r)-x((1:N)-l);
      [maxdo od] = max(d(o));
      odd = o(od);
   end
end

even = setdiff(1:N,odd);
