function [U, C] = updatesemiorth(UP,C)

% updatesemiorth - ThreshLab2/Irregular/1D/ --- update for semi-orth. wav.tr.
%   Usage
%      [U, C] = updatesemiorth(UP,C)
%   Inputs
%      UP  cell array of matrices, the lifting steps
%          alternatively, UP is replaced by {'filterbank',H,G,Ht,Gt}
%      C   Gramian matrix of scaling basis at current resolution level
%   Outputs
%      U   matrix: update step
%      C   matrix: coarser scale version of input C
%   Description
%   Reference
%   Note
%   See also
%      help updateLSapprxprimmom

UP1 = UP{1};
if ischar(UP1),  % UP contains filterbank H,G0,Ht0,Gt
   nUP = length(UP)-1;
   UP = UP(2:nUP+1);
   H = UP{1}; G0 = UP{2};
   if nUP < 4,
      nH = size(H,2); nG0 = size(G0,2);
      Ht0Gt = inv([H G0]);
      Ht0 = Ht0Gt(1:nH,1:nH+nG0)';
      Gt = Ht0Gt(nH+1:nH+nG0,1:nH+nG0)';
   else
      Ht0 = UP{3}; Gt = UP{4};
   end
else
   UPt = duallifting(UP);
   [Ht0 Gt] = refinementfromliftingsteps(UPt);
   [H G0] = refinementfromliftingsteps(UP);
end
if nargin < 2,
   nf = size(H,1);
   Cf = eye(nf);
else
   Cf = C;
end

C = H'*Cf*H;

Ht = Cf'*H/C; % i.e., Ht' = C\(H'*Cf); where we use C=C'
U = Ht'*G0;
