
function Mn = initmom2D(x,y,tri,nn);

% initmom -- ThreshLab2/Irregular/2D/ -- 
%     initializes moments of scaling basis functions at finest scale
%  Usage
%    Mn = initmom(x,y,tri,nn);
%    Mn = initmom(x,y,tri);
%    Mn = initmom(x,y,nn);
%    Mn = initmom(x,y);
%  Inputs
%    x      x-coordinates of scattered data
%    y      y-coordinates of scattered data
%    tri    triangulation of cloud (x,y)
%    nn     n rows, 2 columns matrix; pairs of exponents (default is [0 0])
%  Outputs
%    Mn     matrix of size length(x) times length(nn)
%  Description
%    computes integral(phi_i(x,y)*x^ny^m) with phi(x,y) a hat function on 
%    (x(i),y(i)), this is a polyplane with phi_i(x(i),y(i)) = 1 and
%    phi_i(x(j),y(j)) = 0 if i=/=j
%    This may serve as approximations for the finest scales scaling function
%    moments.
%  See also

if nargin < 3,
   nn = [0 0]; tri = inittri(x,y);
end
if nargin == 3,
   three = size(tri,2);
   if three ~= 3,
      nn = tri;
      tri = inittri(x,y);
   else
      nn = [0 0];
   end
end
if size(nn,2) == 1, nn = nn*[1 1]; end
x = row(x);
y = row(y);
p = size(nn,1);
N = length(x);
if length(y) ~= N, error('dimension mismatch x and y'), end

A = areatri(tri,x,y);

xnxyny = zeros(p,N);
for k = 1:p,
   nx = nn(k,1); ny = nn(k,2);
   xnxyny(k,1:N) = x.^nx.*y.^ny;
end
f = xnxyny';

ntri = size(tri,1);
S = sparse(zeros(N));

Sii = [2 1 1;1 2 1;1 1 2];
for t = 1:ntri,
   i = tri(t,1:3);
   S(i,i) = S(i,i) + Sii*A(t)/12;
end

Mn = S*f;
