
function A = broken2smooth(aa,Omega)

% broken2smooth - ThreshLab2/Irregular/BrokenbasisWT/ --- 
%                 finds coeff. of smooth functions in broken basis
% Usage
%    A = broken2smooth(aa);
%    A = broken2smooth(knots,Omega);
% Inputs
%    aa      cell array of coefficients per segment (length nn), output of
%                              [Phi aa LRknots] = brokenbasis(...)
%    knots   vector of length n; knots of the broken basis
%    Omega   cell array or matrix or integer defining the set of smooth
%            functions from which the broken basis is constructed
%            (for more info: help smoothsetmatrix)
% Outputs
%    A       (ntilde X nn) matrix, so that Omega(x) = Phi(x)*A
%            where Omega(x) = [... Omega_k(x) ...] is the smooth basis
%            and Phi(x) is the basis obtained from brokenbasis(Omega,...)
% Note
% See also
%    help brokenbasis
%    help smoothsetmatrix

if ~iscell(aa), % aa is actually knots
   knots = aa;
   if nargin<2, Omega = 1; end
   % interprete Omega
   [OmegaL Omega] = smoothsetmatrix(knots,Omega);
   if ~isnan(OmegaL(1,1)),
      [aggOmega B] = aggregatesmoothset(OmegaL,Omega);
   else,
      B = NaN;
   end
   aa = brokenbasis(knots,{OmegaL,Omega,'LR'});
elseif nargin>1, B = Omega;
else, B = NaN;
end

nn = length(aa);
nutilde = length(aa{1});
n = nn-nutilde+2;
A = zeros(nn,nutilde);
AA = cell(n-1,1);
for segment = 1:n-1,
   As = zeros(nutilde,nutilde);
   for c = 1:nutilde,
      b = segment+c-1;
      aab = aa{b}; naab = size(aab,2);
      As(1:nutilde,c) = aab(1:nutilde,1);
      aab = aab(1:nutilde,2:naab);
      aa{b} = aab;
   end
   As = inv(As);
   if iscell(B), As = As*B{segment}; end
   sn = (segment:segment+nutilde-1);
   A(sn,1:nutilde) = A(sn,1:nutilde)+As;
end
D = diag([(1:nutilde-1) nutilde*ones(1,n-nutilde) (nutilde-1:-1:1)]);
A = D\A; 
