function H = Bsplinerefinement(xf,ptilde,ext,e)

% Bsplinerefinement - ThreshLab2/Irregular/1D/ --- 
%          finds matrix in two-scale equation for B-splines, using the
%          factoring in lifting steps + special boundary actions
% Usage
%   H = Bsplinerefinement(xf,ptilde,ext,e);
% Input
%   xf     vector of knots
%   ptilde order of splines; 
%                   ptilde=1: constant (Haar-scaling functions)
%                   ptilde=2: linear splines (triangular hat scaling funtions)
%                   ptilde=4: cubic splines
%   ext    binary values: setting ext=true includes B-splines on the boundary
%                         setting ext=false creates nf B-splines, where
%                         nf = length(xf)
%                         (default true)
%   e      vector of integers, indices into xf (default: e = splitevenodd(xf))
% Output
%   H     matrix for which PhiJ*H = PhiL
%         where PhiJ is spline basis, order ptilde, on knots xf
%               PhiL is spline basis, order ptilde, on knots xf(e)
% Note
%   based on
%   UP = liftingstepsBspline(xf,nt);
%   [H G] = refinementfromliftingsteps(UP);
% See also
%   help Bsplinebasisbyrefinement

tol = 1.e-6;
if nargin<3, ext = true; e = splitevenodd(xf); end
if nargin<4, 
   if length(ext)>1, e = ext; ext = true;
   else, e = splitevenodd(xf);
end, end
if length(ext)>1, ee = ext; ext = e; e = ee; end
nf = length(xf); ne = length(e); xe = xf(e);
UP = liftingstepsBspline(xf,ptilde);
H = refinementfromliftingsteps(UP);
if ext==true,
   nff = nf+ptilde-2; nee = ne+ptilde-2;
   s = ceil(ptilde/2)-1; t = floor(ptilde/2)-1;
   xs = xf(1)*(ptilde-1:-1:0)/ptilde+xf(2)*(1:ptilde)/ptilde;
   Phifxs = Bsplinebasis(xs,xf,ptilde); Phifxs = Phifxs(1:ptilde,1:ptilde);
   Phiexs = Bsplinebasis(xs,xe,ptilde); Phiexs = Phiexs(1:ptilde,1:s+1);
   Hnums = Phifxs\Phiexs; Hnums(abs(Hnums)<tol) = 0;
   xt = xf(nf-1)*(ptilde:-1:1)/ptilde+xf(nf)*(0:ptilde-1)/ptilde;
   Phifxt = Bsplinebasis(xt,xf,ptilde); Phifxt = Phifxt(1:ptilde,nf-1:nff);
   Phiext = Bsplinebasis(xt,xe,ptilde); Phiext = Phiext(1:ptilde,ne-1:nee);
   Hnumt = Phifxt\Phiext; Hnumt(abs(Hnumt)<tol) = 0;
   Hint = H; H = zeros(nff,nee);
   H(1:ptilde,1:s+1) = Hnums; H(nf-1:nff,ne-1:nee) = Hnumt;
   H(s+(1:nf),s+(1:ne)) = Hint;
end
