function G = grammatrixBsplines(knots,ptilde)

% grammatrixBsplines - ThreshLab2/Irregular/1D/ --- Gram matrix B-spline basis
% Usage
%   G = grammatrixBsplines(knots,ptilde);
% Input
%   knots   vector of length n; knots of spline basis
%   ptilde  order of splines; ptilde=1: constant (Haar-scaling functions)
%                             ptilde=2: linear splines
%                             ptilde=3: quadratic splines
%                             ptilde=4: cubic splines
% Output
%   G    (n+ptilde-2)x(n+ptilde-2) Gramian matrix
% Description
% See also
%   help allpowercoefsBsplines
%   help Bsplinemoments

knots = column(knots);
n = length(knots);
G = zeros(n+ptilde-2,n+ptilde-2);

l = ceil(ptilde/2)-1; r = floor(ptilde/2)-1;
knotss = [ones(l,1)*knots(1); knots; ones(r,1)*knots(n)];
Xtilde = allpowercoefsBsplines(knotss,ptilde);

x = repmat(knots,1,2*ptilde-1);
q = repmat(0:2*ptilde-2,n-1,1);

M = (x(2:n,1:2*ptilde-1)-x(1:n-1,1:2*ptilde-1)).^(q+1)./(q+1);
% Row i of M, M(i,:) contains the integrals of (x-knots(i))^q over the
% interval (knots(i),knots(i+1))

C = zeros(ptilde,ptilde);
C(1,1:ptilde) = (-1).^(0:ptilde-1);
for q=1:ptilde-1, for r=1:q,
    C(r+1,q+1) = nchoosek(q,r)*(-1)^(q-r);
end, end
for i=1:n-1,
   % for each interknot interval, compute the contributions to the Gramian
   % matrix. Gpower is the Grammian matrix of the power functions.
   Gpower = hankel(M(i,1:2*ptilde-1)); Gpower = Gpower(1:ptilde,1:ptilde);
   Ci = flip(hankel([knots(i).^(ptilde-1:-1:1) 1]))'.*C;
   % Ci is defined by 
   % [1 (x-knots(i)) ... (x-knots(i))^(ptilde-1)] = [1 x ... x^(ptilde-1)]*Ci
   blocki = i+(0:ptilde-1);
   Xtildei = Xtilde(blocki,1:ptilde)*Ci;
   G(blocki,blocki) = G(blocki,blocki)+Xtildei'\Gpower/Xtildei;
end
   
% Undo numerical deviations from symmetry
G = (G+G')/2;
