
function [parents levels] = constructMLPTtree(Ne,odds,hulls);

% constructMLPTtree -- ThreshLab2/Irregular/MultiscaleKernel 
%                      finds tree structure for output of FMLPT1D
%  Usage
%    [parents levels] = constructMLPTtree(Ne,odds,hulls);
%  Inputs
%    Ne       integer; number of coarse scaling coefficients 
%    odds     cell array of integers; refinement points at each scale
%             (see outputs FMLPT1D)
%    hulls    cell array of real values in [0,1] (see outputs FMLPT1D)
%  Outputs
%    parents  integer vector, containing for each component of the MLPT
%             coefficient vector its parent in the tree structure
%    levels   integer vector containing indices into last element of each
%             resolution levels. levels(1) = Ne
%  Description
%     This routine follows the structure of the inverse MLPT (as in IMLPT1D.m)
%  See also
%     help FMLPT1D
%     help IMLPT1D
J = length(odds)+1;


parents = zeros(1,Ne);
parentsevens = parents;
Nj = Ne;
levels = Ne;
Njj = Ne;
for j = 1:J-1,
   Ne = Nj;
   % yeven = y(1:Ne,1:c);
   o = odds{j};
   No = length(o);
   Nj = Ne+No;
   e = setdiff(1:Nj,o);
   % upsample parentsevens => parentsj
   parentsj = zeros(1,Nj);
   parentsj(e) = parentsevens;
   parentsj(o) = parentsj(o-1);
   Q = hulls{j}; Qnon0 = find(Q>eps); Nj1 = length(Qnon0);
   parents = [parents parentsj(Qnon0)];
   parentsj(Qnon0) = (Njj+1:Njj+Nj1);
   parentsevens = parentsj;
   Njj = Njj+Nj1;
   levels = [levels Njj];
end
