function bandwidth = findminbandwidth4multiscalelocpol(x,degree);

% findminbandwidth4multiscalelocpol - ThreshLab2/Irregular/1D/ 
%   Usage
%      h = findminbandwidth4multiscalelocpol(x,degree);
%   Inputs
%      x      vector of observational grid
%      degree degree of polynomial (default 0)
%   Outputs
%      h      bandwidth
%   Description
%      Finds bandwidth such that at all scales a sufficient number of neighbors
%      fall within the bandwidth for proper local polynomial construction of
%      given degree
%   Notes

if nargin<2, degree = 0; end
critical = 0;
n = length(x);
bandwidth = x(n)-x(1);
if n>2*(degree+1), bandwidth = 0; end
scale = 1;
while n>2*(degree+1),
   [even odd] = splitevenodd(n);
   Deltax = x(2:n)-x(1:n-1);
   distL = [Inf Deltax];
   distR = [Deltax Inf];
   [h side] = min([distL; distR]);
   neighL = double(side==1);
   neighR = double(side==2);
   distLL = neighL.*h;
   distRR = neighR.*h;
   for npoints = 2:degree+1,
      % add one point, either left or right
      [h side] = min([distLL+distL(max(1,(1:n)-neighL-1)); ...
                      distRR+distR(min(n,(1:n)+neighL+1))]);
      newL = double(side==1); newR = double(side==2);
      neighL = neighL + newL;
      neighR = neighR + newR;
      distLL(find(newL)) = distLL(find(newL)) + h(find(newL));
      distRR(find(newR)) = distRR(find(newR)) + h(find(newR));
   end
   if critical,
      bandwidth = max(bandwidth,max(h(odd))/scale);
   else
      bandwidth = max(bandwidth,max(h)/scale);
   end
   x = x(even);
   scale = 2*scale;
   n = length(x);
end
