
function [yk dyk] = locpolestimation00(x,x0,y0,h,kerneltype,degree,side);

% locpolestimation00 - ThreshLab2/MultiscaleKernel --- Local polynomial 
%                                                      smoothing
%   Usage
%      for local polynomial smoothing
%         yk = locpolestimation00(x,x0,y0,h,kerneltype,degree,side);
%         [yk dyk] = locpolestimation00(x,x0,y0,h,kerneltype,degree,side);
%      for local polynomial density estimation
%         yk = locpolestimation00(x,X,h,kerneltype,degree,side);   
%      NOTE: this routine has not been implemented yet for use in density
%            estimation (work in progress)
%   Inputs
%      x      x-coordinates in which kernel is evaluated
%      x0     x-coordinates of knots/sample locations in smoothing problem
%      y0     sample observations in smoothing problem
%      X      observations/sample vector in density estimation problem
%      h      kernel bandwidth; scalar or vector of length(x)
%      kerneltype  string-type variable, see evalkernel
%      degree degree of polynomial (default 0)
%      side   -1,0,1: left, both sides, right
%   Outputs
%      yk     local polynomial smoothing evaluated in x
%      dyk    derivatives of yk
%   Notes
%      x, x0 and y0 are supposed to be arranged as rows.
%      if y0 is a square matrix of size equal to the length of x0, then the
%      smoothing operation is performed on all ROWS.
%   See also
%      help evalkernel
%      help kernelestimation

x = row(x);
x0 = row(x0);

nobs = length(x0);
neval = length(x);
[nrows ny] = size(y0);
if nrows == 1 & ny == 1,
   if nargin >= 6, side = degree; else side = 0; end
   degree = kerneltype;
   kerneltype = h;
   h = y0;
   y0 = ones(1,nobs)/nobs;
   densityest = 1;
else
   if nargin < 7, side = 0; end
   densityest = 0;
   if ny ~= nobs, 
      if nrows ~= nobs, error('dimension mismatch x0 and y0')
      else nrows = ny; y0 = y0'; end
   end
end
if ischar(side),
   switch side(1)
   case {'R','r'},
      side = 1;
   case {'L','l'},
      side = -1;
   otherwise,
      side = 0;
   end
end

hh = h;
if length(h) == 1, hh = h*ones(size(x)); end
switch kerneltype
case {'Gaussian','gaussian','gauss','Gauss'}
   kernelsupport = Inf*ones(size(hh));
otherwise
   kernelsupport = hh;
end
% Note that locpolestimation00 constructs the smoothing by a loop over the
% evaluation points in x. This is unlike kernelestimation, where the loop is
% over the knots in x0

yk = zeros(nrows,neval);
for k = 1:degree,
   dyk{k} = zeros(nrows,neval);
end
sk = zeros(size(x));
for i = 1:neval,
   io = (abs(x0-x(i))<kernelsupport(i));
   if side == 1,
      io = io & (x0<=x(i));
   elseif side == -1,
      io = io & (x0>=x(i));
   end
   io = find(io);
   if ~isempty(io),
      xo = x0(io); 
      jo = find(max(abs(y0(1:nrows,io)),[],2)>eps);
      wo = evalkernel(x(i)-x0(io),hh(i),kerneltype);
      yo = y0(jo,io);
      % p = min(degree,length(xo)-1);
      p = degree;
      warningptoohigh = false;
      if nargout == 1,
         yk(jo,i) = weightedLSpol(x(i),xo,yo,wo,p,warningptoohigh);
      else
         [yk(jo,i) dykjoi] = weightedLSpol(x(i),xo,yo,wo,p,warningptoohigh);
         % dykjoi = derivatives of y_k in (jo,i); number of derivatives is
         % min(degree,length(io))
         for k = 1:min(degree,length(io)),
            dykk = dyk{k}; dykk(jo,i) = dykjoi(:,k);
            dyk{k} = dykk;
         end
      end
      % for j = row(jo),
      %    yo = y0(j,io);
      %    p = min(degree,length(xo)-1);
      %    yk(j,i) = weightedLSpol(x(i),xo,yo,wo,p);
      % end
   end
end
