
function [even, odd, BB] = splitbypeelscattered(x,y,varargin)

%  splitbypeelscattered -- partitions data into "even" and "odd" subsets
%  ("even" not necessarily being a multiple of 2)
%   Usage
%     [even, odd] = splitbypeelscattered(x,y);
%   Inputs
%     x,y       coordinates of scattered data
%   Outputs
%     even   indices of even subset
%     odd    indices of odd subset
%   Description
%     The partitioning is organised in a recursive way: first points on the 
%     polyline on the boundary of the data cloud are partitioned, then this
%     boundary polyline is taken away from the data, and a new boundary is
%     defined.
%   Note
%   See also
%     help initboundary (for the definition of the boundary on which the
%                        partitioning takes place)
%     help splitevenodd (for a 1D partitioning)

splitrate = 3/4;
n = length(x);
fine = (1:n);
even = []; odd = [];

nvarargin = length(varargin);
k = 1;
while k <= nvarargin, vark = varargin{k}; if ischar(vark), switch(vark)
   case {'splitrate','rate'}
      splitrate = varargin{k+1};
      k = k+2;
      % note: the current implementation works only with splitrates 
      % 1/4,1/2,3/4
      % The splitrate is the proportion of odds 
   otherwise
      k = k+1;
   end
   else
      k = k+1;
end, end

BB = {};
while length(fine)>2,
   B = initboundary(x(fine),y(fine));
   B = fine(B); nB = length(B)-1; B = B(1:nB); BB = {BB{:},B};
   % following line is for coordinate-independent procedure
   [bmin b1] = min(B); B = frwshift(B,b1-1);
   fine = setdiff(fine,B);
   even = [even B(1:2:nB)];
   odd = [odd B(2:2:nB)];
   if length(fine)>2 & splitrate ~= 1/2,
      B = initboundary(x(fine),y(fine));
      B = fine(B); nB = length(B)-1; B = B(1:nB); BB = {BB{:},B};
      % following line is for coordinate-independent procedure
      [bmin b1] = min(B); B = frwshift(B,b1-1);
      fine = setdiff(fine,B);
      if splitrate == 3/4,
         odd = [odd B];
      else
         even = [even B];
      end
   end
end
even = [even fine];
even = sort(even);
odd = sort(odd);
