
function z = weightedLSpol2D(x,y,x0,y0,z0,w0,px,py);

% weightedLSpol2D- ThreshLab2/Irregular/MultiscaleKernel/ --- 
%                                       2D Weighted Least Squares Polynomial
%   Usage
%      z = weightedLSpol2D(x,y,x0,y0,z0,w0,p);
%      z = weightedLSpol2D(x,y,x0,y0,z0,w0,px,py);
%      z = weightedLSpol2D(x,y,x0,y0,z0,w0,[px py]);
%   Inputs
%      x      x-coordinates in which polynomial is evaluated
%      y      y-coordinates in which polynomial is evaluated
%      x0     x-coordinates of locations where polynonial is constructed
%      y0     y-coordinates of locations where polynonial is constructed
%      z0     z-coordinates of locations where polynonial is constructed
%      w0     weights corresponding to z0 (default = 1)
%      p      degree of polynomial
%   Outputs
%      y      polynomial evaluated in x
%      Dky    derivatives of y
%   Notes
%   See also

if nargin < 6, px = 0; end
if nargin < 7,
   if length(px) > 1,
      py = px(2); px = px(1);
   else
      py = px;
   end
end
n = length(x);
if length(y) ~= n, error('dimension mismatch x and y'); end
n0 = length(x0);
if length(y0) ~= n0, error('dimension mismatch x0 and y0'); end

if nargin < 5, w0 = ones(n0,1); end
if length(w0) == 1, p = w0; w0 = ones(n0,1); end

if size(z0,1) ~= n0, z0 = z0'; end
if size(z0,1) ~= n0, error('dimension mismatch (x0,y0) and z0'); end
if size(w0,1) ~= n0, w0 = w0'; end
if size(w0,1) ~= n0, error('dimension mismatch z0 and w0'); end

if (px+1)*(py+1) > n0,
   pmax = max(px,py);
   pmin = min(px,py);
   if (pmin+1)*(pmin+1) > n0,
      if py>px,
         px = floor(sqrt(n0))-1;
         py = floor(n0/(px+1))-1;
      else
         py = floor(sqrt(n0))-1;
         px = floor(n0/(py+1))-1;
      end
   else
      px = min(px,floor(n0/(pmin+1))-1);
      py = min(py,floor(n0/(pmin+1))-1);
   end
end
x0 = column(x0); y0 = column(y0);
xo = mean(x0); yo = mean(y0);
X0 = zeros(n0,(px+1)*(py+1)); 
k = 0;
for kx = 0:px, for ky = 0:py, 
    k=k+1; X0(1:n0,k) = (x0-xo).^kx.*(y0-yo).^ky;
end, end
X0(1:n0,1) = ones(n0,1); % not strictly necessary
W0 = diag(w0);

X0TW0X0 = X0'*W0*X0;
if cond(X0TW0X0) < 1.e8,
   coef = X0TW0X0\(X0'*W0*z0);
else
   coef = pinv(X0TW0X0)*(X0'*W0*z0);
end
nc = size(coef,2);

transposeresult = 0;
if size(x,2) > 1 & size(x,1) == 1, transposeresult = 1; x = x'; y = y'; end
X = zeros(n,(px+1)*(py+1)); 
k = 0;
for kx = 0:px, for ky = 0:py, 
    k=k+1; X(1:n,k) = (x-xo).^kx.*(y-yo).^ky; 
end, end
X(1:n,1) = ones(n,1); % not strictly necessary


z = X*coef;
if transposeresult, z = z'; end
