
function B = edginside(e,points,x,y)

% edginside - ThreshLab2/Triangulations --- checks if an edge is in the
%                                           interior of a polygone
%   Usage
%     B = edginside(e,points,x,y)
%   Inputs
%     e        pair of integers; indices into data cloud (x,y), defining an
%                                edge
%     points   vector of integers (length 3 or more)
%     x        x-coordinates of 2d-scattered data
%     y        y-coordinates of 2d-scattered data
%   Outputs
%      B       Boolean variable 
%   Description
%      checks if the egde (x(e(1)),y(e(1))) - (x(e(2)),y(e(2))) lies within the
%      polygone defined by x(points),y(points)
%      The order in points is important.
%   See also
%      help pointinedge
%      help edgonboundary

x1 = x(e(1));
x2 = x(e(2));
y1 = y(e(1));
y2 = y(e(2));
n = length(points);
x3 = x(points(n));
x4 = x(points(1));
y3 = y(points(n));
y4 = y(points(1));
B = intersecempty(x1,y1,x2,y2,x3,y3,x4,y4);
for k = 1:n-1
   x3 = x(points(k));
   x4 = x(points(k+1));
   y3 = y(points(k));
   y4 = y(points(k+1));
   B = B & intersecempty(x1,y1,x2,y2,x3,y3,x4,y4); 
end
xx = mean([x1 x2]);
yy = mean([y1 y2]);
B = B & pointinside(xx,yy,points,x,y);
for k = 1:n
   B = B & ~pointinedge(points(k),e,x,y);
end
