
function [points, neighbourtri, t] = findneighbours(v0,tri);

% findneighbours - ThreshLab2/Triangulations --- find adjecent vertcies
%                  in triangulations, or sets of edges
%   Usage
%      [points, neighbourtri, t] = findneighbours(v0,tri);
%      points = findneighbours(v0,E);
%   Inputs
%      tri  triangulation: n rows, 3 columns matrix of indices
%      E    edges: n rows, 2 columns matrix of indices
%      v0   vertex: integer value, i.e., index
%   Outputs
%      points        adjacent vertices (vector of indices)
%      neighbourtri  triangles connecting v0 to its neighbours
%      t             index into rows of tri, so that 
%                    neighbourtri = tri(t,1:3);
%   Description
%   See also

if isempty(tri),
   tri = zeros(0,3);
end
c = size(tri,2);
if c == 2,
   % i.e., find neighbours by edges
   E = tri;
   e = find(sum(E==v0,2));
   E = E(e,:);
   points = setdiff(row(unique(E)),v0);
elseif c < 2,
   error('input variable tri or E cannot be interpreted as triangles or edges')
else
   % c is at least 3, the first 3 columns are interpreted as indexed vertices.
   % Possible further columns are left uninterpreted in this routine (They may
   % contain other attributes of the triangles)
   % Now, find neighbours by triangles
   ntri = size(tri,1);
   t = find(any(tri(1:ntri,1:3)==v0,2));
   neighbourtri = tri(t,1:c);
   E = listedges(neighbourtri);
   e = find(1-sum(E==v0,2));
   E = E(e,:);
   points = row(unique(E));
   if length(points) < size(E,1)+2,
      % if neighbours can be linked in consistent order, do so
      points = linkedges(E);
   end
end
