
function dummy = plotmesh(tri,x,y,varargin)

% plotmesh - ThreshLab2/Triangulations --- plots 2D or 3D meshes
%   Usage
%      plotmesh(tri,x,y,plotoptions)
%      plotmesh(tri,x,y,z,plotoptions)
%   Inputs
%      tri              ntri x 3 integer matrix
%      x                vector of x-coordinates of vertices
%      y                vector of y-coordinates of vertices
%      z                vector of z-coordinates of vertices
%   Optional input
%      matlab's options for plot and plot3
%      'fillcolor',fillcolor   color for shading of triangles
%   Outputs
%      (none)
%   Description
%      example: plotmesh(tri,x,y,f,'fillcolor',[0.5 0.6 1])

h = ishold;
dimension = 2;
fillmesh = false;
plotoptions = {};
N = length(x);
if N ~= length(y),
   warning('x and y have dissimilar lengths')
   N = min(N,length(y));
end
if max(max(tri)) > N,
   error('tri has indices beyond range of (x,y)')
end
if min(min(tri)) < 1,
   error('tri has zero or negative indices')
end
z = zeros(size(x));
nvarargin = length(varargin);
if nvarargin > 0,
   k = 1;
   vark = varargin{1};
   if length(vark) == N, z = vark; k = 2; dimension = 3; end
   while k < nvarargin,
      vark = varargin{k};
      if ischar(vark),
         vark2 = [vark '         '];
         vark2 = vark2(1:9);
         if vark2 == 'fillcolor',
            fillcolor = varargin{k+1};
            fillmesh = true;
            k = k+1;
         else
            plotoptions = {plotoptions{:},vark};
         end
      else
         plotoptions = {plotoptions{:},vark};
      end
      k = k+1;
   end     
   if k == nvarargin,
      vark = varargin{k}; plotoptions = {plotoptions{:},vark};
   end
end

if fillmesh,
   ntri = size(tri,1);
   for t = 1:ntri,
      xt = x(tri(t,1:3)); yt = y(tri(t,1:3)); zt = z(tri(t,1:3));
      fill3(xt,yt,zt,fillcolor)
      hold on
   end
else
   E = listedges(tri);
   nE = size(E,1);
   for e = 1:nE
       x1 = x(E(e,1));
       x2 = x(E(e,2));
       y1 = y(E(e,1));
       y2 = y(E(e,2));
       z1 = z(E(e,1));
       z2 = z(E(e,2));
       if dimension == 2,
          plot([x1 x2],[y1 y2],plotoptions{:})
       else
          plot3([x1 x2],[y1 y2],[z1 z2],plotoptions{:})
       end
       hold on
   end
   if ~h
      hold off
   end
end
xmin = min(x);
xmax = max(x);
ymin = min(y);
ymax = max(y);
zmin = min(z);
zmax = max(z);
if dimension == 2,
   axis([xmin xmax ymin ymax])
end
   
