
function B = pointonline(x0,y0,x1,y1,x2,y2,tol,open);

% pointonline - ThreshLab2/Triangulations --- checks if a point lies on the
%               line segment defined by two other points (within a tolerance)
%   Usage
%     B = pointonline(x0,y0,x1,y1,x2,y2,tol,open);
%   Inputs
%     (x0,y0)  x and y coordinates of a point
%     (x1,y1)  x and y coordinates of one end point of a line segment
%     (x2,y2)  x and y coordinates of the other end point of a line segment
%     tol      tolerance
%     open     Boolean variable (indicates whether line segment is considered
%              to be open or closed)
%   Outputs
%      B       Boolean variable 
%   Description
%      checks if (x0,y0) is on the line segment (x1,y1)-(x2,y2)
%   See also
%      help pointinside
%      help pointinedge
%      help pointonboundary
%      help pointonpolyline

if nargin < 7, tol = 1.e-6; end
if nargin < 8, open = true; end %line segment can be open or closed

% B1 = colinear(x0,y0,x1,y1,x2,y2,tol);
% with colinear the tolerance is interpreted in a determinant expression; We
% prefer the tolerance to be the maximum distance from (x0,y0) to the line
% through (x1,y1) and (x2,y2)
D = abs((y2-y1).*x0-(x2-x1).*y0+x2.*y1-y2.*x1)./...
    sqrt((y2-y1).^2+(x2-x1).^2);
B1 = (D < tol);
% Now check if point is in the right segment
if open == true,
   B2 = ((x0-x1).*(x2-x0)>tol);
   B3 = ((y0-y1).*(y2-y0)>tol);
else % to be verified
   B2 = ((x0-x1).*(x2-x0)>-tol);
   B3 = ((y0-y1).*(y2-y0)>-tol);
end
B = B1 & (B2 | B3);
