
function segment = pointonpolyline(x0,y0,x,y,tol);

% pointonpolyline - ThreshLab2/Triangulations --- checks if a point lies on a
%                                             polyline (within some tolerance)
%   Usage
%      segment = pointonpolyline(x0,y0,x,y,tol);
%   Inputs
%     x0,y0    coordinates of a vertex/point in the plane
%     x        x-coordinates of polyline
%     y        y-coordinates of polyline
%   Outputs
%     segment  integer; 0 if p0 not on polygon defined by points
%                       otherwise index into (x,y)
%   Note
%      Unlike pointonboundary, pointonpolyline does not implicitly assume
%      closed polylines
%   See also
%      help pointinside
%      help pointinedge
%      help pointonline
%      help pointonboundary

if nargin<5, tol = 1.e-6; end
segment = 0;
n = length(x);
if n ~= length(y), error('inconsistent polyline definition'), end
for p=1:n-1,
   x1 = x(p); y1 = y(p); x2 = x(p+1); y2 = y(p+1);
   if pointonline(x0,y0,x1,y1,x2,y2,tol),
      segment = p;
   end
   if norm([x1-x0 y1-y0]) < tol,
      segment = [p-1 p];
   end
end
if norm([x2-x0 y2-y0]) < tol,
   segment = [n-1 0];
end
