
function LL = LLmarg0inflCauchyJSplusnormal(pp,stdev,y);

% LLmarg0inflCauchyJSplusnormal -- marginal log-likelihood for zero inflated
% JScauchy + standard normal noise
%   Usage
%      LL = LLmarg0inflCauchyJSplusnormal(pp,stdev,Y);
%      LL = LLmarg0inflCauchyJSplusnormal(pp,Y);
%   Inputs
%      Y     observations
%      pp    sparsity parameter value
%      stdev value for st.dev. of noise (default 1)
%   Outputs
%      LL    marginal log likelihood of parameters given Y
%   Description
%      The model is Y = X + stdev*Z, with
%      p = P(X =/= 0)
%      X|X=/=0 ~ JScauchy(stdev)
%      Z ~ NID(0,1)
%   Reference
%     The Cauchy-like distribution JScauchy comes from:
%     I. Johnstone and B. Silverman, Needles and Straw in Haystacks, Annals of
%                                    Statistics, 2004.
%   See also
%     help LLmarg0inflLaplaceplusnormal
%     help JScauchyplusnormalpdf

if nargin < 3,
   y = stdev;
   stdev = 1;
end

qq = 1-pp;

np = length(pp);
LL = zeros(size(pp));
for i = 1:np,
   p = pp(i); q= 1-p;
   LL(i) = sum(log(p*JScauchyplusnormalpdf(y,stdev) + q*gauss(y,stdev)));
end
