
function [mse betahat] = MSEitthresh(beta,Y,K,t,maxit,betahat0,softORhard);

% MSEitthresh -- apply iterative soft/hard threshold 
%                + compute mean squared error (MSE)
%  Usage
%    [mse betahat] = MSEitthresh(beta,K,Y,t,softORhard,betahat0);
%  Inputs
%    beta   noise-free sparse data
%    Y      observed vector: Y = K*beta + noise
%    K      model of covariates (rectangular matrix)
%    t      threshold (must be scalar)
%    maxit  maximum number of iterations (default is 1000)
%    betahat0  initial value for betahat (default is zero)
%    softORhard boolean: 1 for soft; 0 for hard (default is 1)
%  Outputs
%    mse    the value of the mse of betahat
%    betahat   estimate of sparse vector beta
%  Description
%    Applies soft- or hard threshold t to all elements of Y and computes MSE
%  Note/See also
%    

[n m] = size(K);
if nargin < 7, softORhard = 1; end
if nargin < 6, betahat0 = zeros(m,1); end
if nargin < 5, maxit = 1000; end

if isnan(maxit), maxit = 1000; end
if isnan(betahat0) | betahat0 == 0, betahat0 = zeros(m,1); end

if softORhard == 0,
   betahat = iterativeHT(Y,K,t,maxit,betahat0);
else
   betahat = iterativeST(Y,K,t,maxit,betahat0);
end
mse = norm(betahat-beta)^2/m;
