
function [wt, thr] = minmsehard(v,w,s)

% minmsehard -- apply hard threshold with minimum MSE threshold
%                    MSE = Loss = mean squared error
%  Usage
%    [wt, thr] = minmsehard(v,w);
%    [wt, thr] = minmsesoft(v,w,s);
%  Inputs
%    v      noise-free input vector
%    w      observed input vector
%    s      vector of size(w) (default value is 1)
%  Outputs
%    wt     thresholded vector
%    thr    minimum MSE threshold
%  Description
%    Applies minimum MSE hard threshold HT(w,s*thr) to all elements of w
%  Note
%
%  See also
%    help MSEhard
%    help minmsethreshest

if nargin == 3,
   [wt, thr] = minmsethreshest(v,w,s,0);
else
   [wt, thr] = minmsethreshest(v,w,0);
end

% Copyright (c) Maarten Jansen
%
% This software is part of ThreshLab and is copyrighted material. 

