
function [Rh Ekappahat] = hardrisk(t,beta,stdev);

% hardrisk -- expected L2-loss in hard thresholding data with normal noise
%  Usage
%    [Rh Ekappahat] = hardrisk(t,beta,stdev);
%  Inputs
%    t      threshold, or vector of thresholds
%    beta   vector of noise-free data
%    stdev  standard deviation of normal noise (to be added to beta) 
%  Outputs
%    Rh         hard threshold risk = expected L2-loss
%    Ekappahat  expected model size
%  Description
%    computes risk when thresholding w = beta+noise where noise ~ N(0,stdev^2)
%  Note
%    This routine cannot be used for plotting the risk in a single coefficient
%    as a function of that coefficient's value: the function takes all values
%    of beta as a data vector.
%  See also:
%    help softrisk

if nargin < 3, stdev = 1; end
if nargin < 2, beta = 0; end
betacol = column(beta);
trow = row(t);
n = length(beta);
m = length(t);
t = repmat(trow,n,1);
beta = repmat(betacol,1,m);
stdev2 = stdev*stdev;
tbeta = t+beta;
t_beta = t-beta;

Rh1 = stdev2*(tbeta).*gauss(tbeta,stdev)+stdev2*t_beta.*gauss(t_beta,stdev);
Rh2 = stdev2*(1-cumgauss(tbeta,stdev))+stdev2*(1-cumgauss(t_beta,stdev));
Rh3 = beta.*beta.*(cumgauss(tbeta,stdev)+cumgauss(t_beta,stdev)-1);
Rh = Rh1+Rh2+Rh3;

Rh = sum(Rh,1)/n;
if nargout>1,
   Ekappahat = sum(Rcumgauss(tbeta,stdev)+Rcumgauss(t_beta,stdev));
end

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
