
function bias = softbias(l,beta,stdev);

% softbias -- bias in soft thresholding data with normal noise
%  Usage
%    bias = softbias(t,beta,stdev);
%  Inputs
%    t      threshold, or vector of thresholds
%    beta   vector of noise-free data
%    stdev  standard deviation of normal noise (to be added to beta)
%  Outputs
%    bias   norm of soft threshold bias
%  Description
%    computes bias when thresholding Y = beta+noise where noise ~ N(0,stdev^2)
%    i.e., E(ST(Y)) - beta where ST = soft-threshold function
%  Note
%  See also:
%    help softrisk
%    help ST

betacol = column(beta);
lrow = row(l);
n = length(beta);
m = length(l);
l = repmat(lrow,n,1);
beta = repmat(betacol,1,m);

Ebetahat1 = stdev^2*(gauss(l-beta,stdev) - gauss(l+beta,stdev));
Ebetahat2 = l.*(cumgauss(l-beta,stdev) - cumgauss(l+beta,stdev));
Ebetahat3 = beta.*(1 - cumgauss(l-beta,stdev) - cumgauss(l+beta,stdev));
Ebetahat = Ebetahat1 + Ebetahat2 + Ebetahat3;
bias = sqrt(sum(Ebetahat.*Ebetahat)/n);

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
