
function [cv Wt] = CVsparseselection(Y,Wt,S,nleaveout,doST)

% CVorth -- Cross Validation for selection in sparse data transforms
%  Usage
%    cv = CVsparseselection(Y,Wt,S,nleaveout,doST);
%  Inputs
%    Y            real vector, length n, containing data
%    Wt           n times n orthogonal matrix or cell describing transform
%    S            integer vector or cell of integer vectors (default (1:n))
%    nleaveout    number of points left out in CV (default 1)
%    doST         boolean, true for soft thresholding (default false)
%  Outputs
%    gcv          the value of the cross validation
%  Description
%    Applies selections in S and computes corresponding cross validation

n = length(Y);
Y = column(Y);
if iscell(Wt)
   nWt = length(Wt);
   if nWt==2 & isreal(Wt{1}),
      W = Wt{2}; Wt = Wt{1};
   else
      Wt = feval(Wt{1},Wt{2:nWt}); W = inv(Wt);
      Sigmaw = Wt*Wt'; stdevw = sqrt(diag(Sigmaw));
      Wt = diag(1./stdevw)*Wt; W = W*diag(stdevw);
   end
else
   W = inv(Wt);
end
w = Wt*Y;
if nargin<3, S = (1:n); end
if nargin<4, nleaveout = 1; end
if nargin<5, doST = false; end
nk = length(S);
if isreal(S), 
   Svec = S; S = cell(1,nk); for k=1:nk, S{k} = Svec(1:k); end
end

m = floor(n/nleaveout);
YY = Y*ones(1,m);
Yext = [Y(2);Y;Y(n-1)];
II = zeros(n,m);
for v=1:m,
   II(v:m:n,v) = 1;
   YY(v:m:n,v) = (Yext(v:m:n)+Yext(v+2:m:n+2))/2;
end
if any(sum(II,2)<1), warning('incomplete leave out'); end
if any(sum(II,2)>1), warning('overcomplete leave out'); end
ww = Wt*YY;
cv = zeros(1,nk);
for k = 1:nk,
   Sk = S{k};
   wwk = zeros(size(ww)); wwk(Sk,1:m) = ww(Sk,1:m);
   if doST, thr = min(abs(w(Sk))); wwk(Sk,1:m) = ST(ww(Sk,1:m),thr); end
   YYk = W*wwk; Yk = sum(II.*YYk,2);
   cv(k) = norm(Yk-Y)^2/n;
end
