
function [w cc parents] = FAUHT(x,y,gamma);

%  FAUHT -- forward adaptive unbalanced Haar transform/1D-CART
%   Usage
%     [w cc parents] = FAUHT(x,y,c);
%   Inputs
%     x      real vector; grid-locations of observations (time, space)
%     y      real vector; response variables
%     gamma  (optional; default 1) contrast coefficient
%   Outputs
%     w       vector of size(y) containing offset/detail coefficients
%     cc      permutation of (1:length(y)); ordered list of splitting points
%     parents index vector of size(y); describing tree structure (see below)
%   Description
%     Forward adaptive unbalanced Haar transform, constructing classification
%     and regression tree on 1D signal
%   Note
%   See also
%     help FAUHTfromrefinement
%     help parentschildren (for more info on tree representation)

if nargin<3, gamma = 1; end
transpose = false;
n = length(x);
if nargin<2, y = x; x = makegrid(0,n); end
x = column(x); if size(y,1) ~= n, y=y'; transpose = true; end
M = row(initmom(x)); M([1 n]) = 2*M([1 n]);
w = zeros(size(y));
w(1) = M*y/sum(M);
k = 1;
II = [0 n]; % II equals [0 sort(cc)-1 n]
II2w = 1; % IIw contains index into w, where IIw(i) points to the coefficient 
          % that has created the subinterval (II(i)+1,II(i+1)) (this will be
          % the parent of the coefficient that will split this subinterval)
          % length of II2w = length of II minus one
while k<n,
   III = II(1); % III is refinement of II
   III2w = [];
   nII = length(II)-1;
   for i=1:nII,
      lengthI = II(i+1)-II(i);
      if lengthI>1,
         I = (II(i)+1:II(i+1));
         W1 = ones(lengthI-1,1)*M(I);
         % equidistant: W1 = ones(lengthI-1,lengthI);
         WR = triu(W1,1); WR = diag(1./sum(WR,2))*WR;
         WL = tril(W1); WL = diag(1./sum(WL,2))*WL;
         WI = WR-WL;
         wI = WI*y(I);
         [wmax c] = max(abs(wI)./sqrt(sum(WI.^2,2)).^gamma);
                  % max(abs(wI)./sum(WI.^2,2));
                  % max(abs(wI));
                  % max(abs(wI)./sqrt(sum(WI.^2,2))); 
                  % normalisation/standardisation
         k = k+1;
         w(k) = wI(c);
         c = II(i)+c;
         cc(k) = c;
         parents(k) = II2w(i);
         III = [III c];
         III2w = [III2w k k];
      else
         III2w = [III2w II2w(i)];
      end
      III = [III II(i+1)];
   end
   II = III; II2w = III2w;
end
if transpose==true, w=w'; end
