function y = IAUHT(x,w,cc);

%  IAUHT -- inverse adaptive unbalanced Haar transform
%   Usage
%     y = IAUHT(x,w,cc);
%   Inputs
%     x      real vector; grid-locations of observations (time, space)
%     w      vector of size(x) containing offset/detail coefficients
%     cc      permutation of (1:length(y)); ordered list of splitting points
%   Outputs
%     y      real vector; reconstructed response variables
%   Description
%     Reconstruction from adaptive unbalanced Haar transform.
%   Note
%   See also
%     help FAUHT


n = length(x);
if nargin<2, w = x; x = makegrid(0,n); end
x = column(x); if size(w,1) ~= n, w=w'; end
m = size(w,2);
M = row(initmom(x)); M([1 n]) = 2*M([1 n]);
y = ones(n,1)*w(1,1:m);
II = [0 n];
for k = 2:n,
   c = cc(k);
   i = max(find(II<c));
   II = [II(1:i) c II(i+1:k)];
   IL = (II(i)+1:II(i+1)); IR = (II(i+1)+1:II(i+2));
   MIL = sum(M(IL)); MIR = sum(M(IR));
   a = MIR/(MIL+MIR);
   y(IL,1:m) = y(IL,1:m) - a*w(k);
   y(IR,1:m) = y(IR,1:m) + (1-a)*w(k);
end

