
function [E W] = graphedges(G,symmetric);

% graphedges - ThreshLab/Trees
%   Usage
%     E = graphedges(G,symmetric);
%     [E W] = graphedges(G,symmetric);
%   Inputs
%     G         matrix representing graph
%     symmetric boolean (default true)
%   Outputs
%     E   two column integer matrix with indices into G, pointing at
%         non-diagonal nonzeros 
%     W   real vector containing weights of edges (entries of G)
%   Note
%     W = G(E(:,1)+(E(:,2)-1)*size(G,1));
%   See also
%     help edges2graphmatrix

if nargin<2, symmetric=true; end
[i j] = find(abs(G)>eps); i = column(i); j = column(j);
E = [i j];
if symmetric,
   r = find(i<j);
else
   r = find(i~=j);
end
if length(r)>0,
   E = E(r,1:2);
else
   E = zeros(0,2);
end
W = G(E(:,1)+(E(:,2)-1)*size(G,1));
