
function [Kappa, E, Sigma] = makesparseconcentrationmatrix(varargin);

% [Kappa, E, Sigma] = makesparseconcentrationmatrix(x,y);
nvarargin = length(varargin);
method = 'maxneighbours';
listmethods={'maxneighbours','maxneighbors','HTH','delaunay'};
x = NaN; y = NaN; p = NaN; a = 1/5; m = NaN; kappatrue = NaN;
for k=1:nvarargin, vark = varargin{k};
   if ischar(vark), if ismember(vark,listmethods), method = vark; end, end
   if isnumeric(vark), 
      if max(size(vark))>1, 
         if isnan(x), x = vark; m = length(x);
         elseif isnan(y) & length(vark)==m, y = vark;
         end
      elseif 0<vark & vark<1 & isnan(p), p = vark; 
      elseif isnan(m), m = vark;
      else, kappatrue = vark; 
      end
   end
end
if length(y) ~= length(x), error('dimension mismatch x and y'), end
if isnan(m), m = 1000; end

findE = false;
switch method
case {'HTH'},
   if isnan(p), p = 0.005; end, if isnan(a), a = 1/5; end
   mm = m*m;
   nnon0 = floor(p*m*(m-1)/2); % p = relative number of nonzero off-diagonal
                               % elements in concentration matrix Kappa
   nnon0 = max(1,nnon0);
   lowertri = find(reshape(1-triu(ones(m,m)),mm,1));
   if isnan(x),
      nonzeros = lowertri(randperm(m*(m-1)/2,nnon0));
   else,
      o = ones(size(x));
      Dist = sqrt((o*x'-x*o').^2+(o*y'-y*o').^2);
      dd = reshape(Dist,mm,1); [dd oo] = sort(dd(lowertri));
      nonzeros = lowertri(oo(1:nnon0));
   end
   nnon0 = length(nonzeros);
   HH = zeros(1,mm);
   HH(nonzeros) = randlaplace(nnon0,1,a);
   H = reshape(HH,m,m);
   Kappa = H'+H;
   L = eig(Kappa); D = ((max(L)-min(L))*0.2-min(L))*eye(m);
   Kappa = D+Kappa;
   findE = true;
case {'delaunay'}
   % generate graph as subset of Delaunay triangulation 
   if isnan(p), p = 0.005; end
   if isnan(kappatrue), % this should be interpreted as degree of sparsity
      kappatrue = p*m*(m-1);
   end
   if isnan(x), [x y] = makegrid2(m,0); end
   tri = inittri(x,y);
   E = listedges(tri);
   nE = size(E,1); kappatrue = min(kappatrue,nE);
   ee = randperm(nE);
   if nE > kappatrue, ee = ee(1:kappatrue); end
   E = E(ee,1:2);
   % se = sign(rand(1,kappatrue)-0.5);
   % rhoe = rand(1,kappatrue).*se;
   rhoe = rand(1,kappatrue)*2-1;
   Kappa = eye(m);
   for e=1:kappatrue,
      i = E(e,1); j = E(e,2);
      Kappa(i,j) = rhoe(e);
      Kappa(j,i) = rhoe(e);
   end
   % The elements of Kappa=inv(Sigma) are possible values in a precision matrix
   % (=inverse covariance matrix)
   % Indeed, any positive definite matrix can be a covariance matrix, and the
   % inverse of a positive definite matrix is again positive definite. So, an
   % arbitrary precision matrix can be constructed as an arbitrary covariance
   % matrix.
   % The procedure above does not guarantee a positive definite matrix
   %   https://en.wikipedia.org/wiki/Diagonally_dominant_matrix
   %   https://en.wikipedia.org/wiki/Sylvester's_criterion
   %   https://en.wikipedia.org/wiki/Covariance_matrix
   % Therefore, make Kappa diagonally dominant:
   AbsOff = abs(Kappa)-eye(m);
   SumAbsOff = max(1,sum(AbsOff));
   D = diag(1./SumAbsOff);
   Kappa = D*(Kappa-eye(m))*D+eye(m);
case {'maxneighbours','maxneighbors'}
   % cfr. Meinshausen, Bühlmann, 2006, AnnStat
   nemax = kappatrue;
   if isnan(nemax), nemax = 4; end
   if isnan(x), [x y] = makegrid2(m,0); end
   o = ones(size(x));
   D = sqrt((o*x'-x*o').^2+(o*y'-y*o').^2);
   % pp = 2*Rcumgauss(D/sqrt(m));
   pp = 2*Rcumgauss(20*D);
   % p = q+q-q^2 <=> q^2-2q+p = 0 <=> (q-1)^2 + (p-1) = 0 <=> q = 1-sqrt(1-p)
   %                                  (and 0<q<1)
   qq = 1-sqrt(1-pp);
   R = rand(size(qq));
   Kappa = (R<qq);
   Kappa = min(1,Kappa+Kappa');
   Kappa = max(0,Kappa-eye(m));
   Kappasum = Kappa*ones(m,1);
   % first remove ones from Sigma where both the row and the column have too
   % many ones
   while any(Kappasum>nemax),
      k = find(Kappasum>nemax); i = randperm(length(k)); k = k(i(1));
      l = find(Kappa(k,:)==1);
      l2 = l(Kappasum(l)>nemax); if length(l2)>0, l=l2; end
                             i = randperm(length(l)); l = l(i(1));
      Kappa(k,l) = 0; Kappa(l,k) = 0;
      Kappasum([k l]) = Kappasum([k l])-1;
   end
   % Define concentrationmatrix
   if nemax>0,
      Kappa = Kappa*(1/nemax-0.005)+ eye(m);
   else
      Kappa = diag(rand(m,1));
   end
   % cfr. Meinshausen, Bühlmannn: 0.245 for nemax = 4;
   findE = true;
end
if findE==true,
   E = graphedges(Kappa);
end
% Finally, find explicit form for Sigma and standardize
Sigma = inv(Kappa);
D = diag(sqrt(diag(Sigma)));
Kappa = D*Kappa*D;
Sigma = D\Sigma/D;
