function mhat = montecarlomirrorAUHT(x,gam)

% montecarlomirrorAUHTn - ThreshLab/Trees - Mirror correction in 
%                                           regression tree pruning (CART)
%   Usage
%     mhat = montecarlomirrorAUHTn(x,gam);
%   Inputs
%     x    locations (time/space) of observations (default equispaced on [0,1])
%     gam  parameter in FAUHT
%   Outputs
%     mhat numerically (Monte-Carlo) computed approximation of offset between
%          degrees of freedom after selection and selection size (mirror)
%   Note
%     publications on the mirror correction adopt
%        mirror = (nu-kappa)*stdev^2/n, hence mhat = (nuhat-kappa)*stdev^2/n
%             (with nu as d.o.f. and kappa as model size)
%     as definition. In this routine, stdev^2 is not involved. Hence, the
%     output should be multiplied with stdev^2 in order to correspond to the
%     definition used in the publications.
%   See also
%     help montecarlomirrorAUHT
%     help FAUHT



if nargin<2, gam = 1; end
if length(x)==1,
   n = x; x = makegrid(n,0); 
else
   n = length(x);
end
Z = randn(1,n);
[w cc parents] = FAUHT(x,Z,gam);
I = eye(n);
Wt = FAUHTfromrefinement(x,I,cc);
Sigmaw = Wt*Wt';
stdevw = row(sqrt(diag(Sigmaw)));
w = w./stdevw;


[sumZ2subtree subtrees] = maxmassubtree(w.^2,parents);

mhat = (sumZ2subtree-(1:n))/n;
