
function tree = randombinarysubtree(n,n1,parents);

% randombinarysubtree - ThreshLab/Trees
%   Usage
%     tree = randombinarysubtree(n,n1,parents);
%   Inputs
%     n       integer; size of full binary tree
%     n1      integer; size of subtree
%     parents vector of integers
%   Outputs
%     tree   n1-tuple of integers in {1,2,...,n}
%   Description
%     Selects a random rooted subtree of the binary tree with depth
%     floor(log2(n+1))
%     The output is a set of indices referring to the positions of the knots in
%     the full tree that belong to the subtree. The index system of the full
%     tree is as follows:
%     The root (level 0) of the tree and the subtree has index 1. 
%     The knots of the full tree at the next level (j=1) have indices 2 and 3. 
%     In general, the k-th knot at level j has index i=2^j+k,
%     where j = 0,1,.... and k = 0,...,2^j-1. 
%     Its offsprings have indices 2*i and 2*i+1.
%   See also
%     help showasgreyleveltree
%     help allbinarysubtrees
%     help maxmassubtree

if n<n1, n = 2^n; end
if nargin < 3, parents = floor((1:n)/2); end
if min(size(parents))==2,
   children = parents;
   if size(children,2) ~= 2, children = children'; end
   c1 = find(children(1:end,1)>0);
   c2 = find(children(1:end,2)>0);
   parents = zeros(1,n);
   parents(children(c1,1)) = c1;
   parents(children(c2,1)) = c2;
end
[parents reorder] = sort(parents);
p0 = max(find(parents==0));
children = zeros(n,2)*(n+1); 
children(parents(p0+1:2:n),1) = (p0+1:2:n);
children(parents(p0+2:2:n),2) = (p0+2:2:n);

tree = zeros(1,n1);
if n1>0, tree(1:p0) = 1; end
candidates = [children(1:p0,1); children(1:p0,2)]';
nc = length(candidates);
for i = 2:n1,
   candidates = candidates(find(candidates>0));
   nc = length(candidates);
   candidates = candidates(randperm(nc));
   l = candidates(1);
   tree(i) = l;
   candidates = [candidates(2:nc) children(l,1:2)];
end

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
