
function treekk = reconstructsubtree(parents,trees,kk,dummies)

% reconstructsubtree - ThreshLab/Trees -- postprocessing of maxmassubtreeXL
%   Usage
%     treekk = reconstructsubtree(parents,trees,kk,dummies);
%     treekk = reconstructsubtree(children,trees,kk,dummies);
%   Inputs
%     parents  integer vector of size(x), indices into x, for each element of x
%              containing the index of its ancestor 
%              (same as in maxmassubtreeXL)
%     children cell or integer matrix, indices into x 
%     trees    compressed representation of all best k-subtrees of full tree
%     kk       vector of integers
%     dummies  (optional) vector of integers (see maxmassubtreeXL for explanation)
%   Outputs
%     treekk   cell of integer vectors; containing best k-subtrees for all k in
%              kk
%   See also
%     help maxmassubtreeXL 

if nargin < 4, dummies = []; end 
n = length(parents);
if length(dummies)==n & all(ismember(dummies,[0 1])),
   isdummy = dummies; dummies = find(isdummy);
else
   isdummy = ismember(1:n,dummies);
end

% make sure to have parents as input
[parents children] = parentschildren(parents);

% add one superroot  (as in maxmassubtreeXL)
parents = [0 parents+1];

if ~isempty(dummies), dummies = dummies+1; end
isdummy = [false isdummy];

% Now, find the children
children = parentschildren(parents,'cell');
childrencopy = children;

nnodeswithc = length(children); % nodes beyond nnodeswithc cannot possibly 
                                % have children
                                % (other nodes may or may not have children)

nk = length(kk);
if nk > 1, treekk = cell(1,nk); end
for i = 1:nk,
   % first find best (k+1)-subtree in tree with superroot
   k = kk(i)+1;
   nodes = 1;  % nodes is vector of nodes in order of processing (todo list)
   nodesk = k; % nodesk contains for every node in nodes the size of the
               % subtree rooted in it (i.e., the number of nodes to look for in
               % the set of offsprings of the corresponding node in the vector
               % nodes)
   nnodes = 1; % nnodes = length(nodes)
   treek = [];
   while nnodes>0,
      p = nodes(1);
      s = nodesk(1); % so parent node p roots a subtree of size s
      treek = [treek p];
      if p<=nnodeswithc,
         cc = children{p}; cc = cc(end:-1:1);
         if length(cc)>0, for c=row(cc), if s>0,
            nodesc = trees{c}(s); 
            % child c has a subset of size nodesc of the size s subtree of p
            if nodesc>0,
               s = s-nodesc; % compute what is left over for the next children
               % if this child is a dummy, then it should be included without
               % counting for the size of the tree. So the real size of the
               % tree (with the dummies included) and the size of the subtree
               % rooted at the dummy c should go up by 1.
               if isdummy(c), nodesc = nodesc+1; k = k+1; end
               % Add the child to the todo list
               nodes = [nodes c];
               nodesk = [nodesk nodesc];
            end
         end, end, end
      end
      nnodes = length(nodes);
      nodes = nodes(2:nnodes);
      nodesk = nodesk(2:nnodes);
      nnodes = nnodes-1;
% disp(['nodes = ' num2str(nodes) '; treek = ' num2str(treek)])
   end
   % second, remove superroot + undo its effect
   treek = treek(2:k)-1;

   if nk>1, treekk{i} = treek; end
end
if nk==1, treekk = treek; end

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
