
% Simulation study for finetuning kappa in the best kappa-tree selection
% applied to the adaprtive unbalanced Haar transform (CART) on Poisson
% observations.
% To be compared to simulationstudyjansen07changepoint.m
% in /ThreshLab/ThreshLab2/ContinuousUnbalancedHaar/
% This simulation study runs nsimul times the routine
%     illustrateAUHTtreedenoising 

if exist('writeoutput') ~= 1, writeoutput=true; end
if exist('forceplots') ~= 1, forceplots=false; end
if exist('plotsimulationsummary') ~= 1, plotsimulationsummary=true; end
samplesize = 4000;
x = makegrid(samplesize,0);
mu = blocks(x) + 3.5;

CPmu = find(mu(2:samplesize)~=mu(1:samplesize-1))+1;
nCPmu = length(CPmu);
% CPmu:  true change points
% Set up number of simulations and starting seed
realrandom = 1;
% realrandom=1 as argument in y = poissonnoise(f,realrandom); makes sure that every
% simulation run works with different y
if exist('usesavedseed') ~= 1, usesavedseed = false; end
if usesavedseed,
   seed = load('seedsave')
else
   seed = 1
end
% rand('state',seed); randn('state',seed);
if ~exist('nsimul'), nsimul = 200; end
% Now, run:

pdfy = 'poisson';

numberofCPfound = zeros(1,nsimul);
nfalsepositivenodes = zeros(1,nsimul);
nfalsepositiveleaves = zeros(1,nsimul);
estimate = ones(nsimul,nCPmu)*NaN;
makeplots = false; setupdata = false;
if forceplots, makeplots = true; end
for simul = 1:nsimul,
disp('-----------------------------------------------------------------')
disp(['      simul: ' num2str(simul)])
disp('-----------------------------------------------------------------')
   disp([' seed = ' num2str(seed)])
   rand('state',seed); randn('state',seed); seed = seed+1000;
   Y = poissonnoise(mu,realrandom);
   % run illustrateAUHTtreedenoising twice. From the first run, use the output
   % Ythr for variance estimation. From the second run, use the output Ytree as
   % final outcome. (In practice, all this could be integrated into a single
   % run, saving 50% of the computation time)
   SigmaY = diag(Y);
   illustrateAUHTtreedenoising
   SigmaY = diag(Ythr);
   illustrateAUHTtreedenoising

   numberofCPfound(simul) = length(CPYtree);
   estimate(simul,1:nCPmu) = match1;
   nfalsepositivenodes(simul) = length(falsepositivenodes);
   nfalsepositiveleaves(simul) = length(falsepositiveleaves);

   if writeoutput==true,
      fid = fopen('resultssimulationstudychangepointpoissonAUHT.m','w');
      fprintf(fid,'estimate = [');
      for i = 1:simul,
         fprintf(fid,'\n');
         fprintf(fid,'%d ',estimate(i,:));
      end
      fprintf(fid,'];\n');
      fprintf(fid,'numberofCPfound = [');
      fprintf(fid,'%d ',numberofCPfound(1:simul));
      fprintf(fid,'];\n');
      fprintf(fid,'nfalsepositivenodes = [');
      fprintf(fid,'%d ',nfalsepositivenodes(1:simul));
      fprintf(fid,'];\n');
      fprintf(fid,'nfalsepositiveleaves = [');
      fprintf(fid,'%d ',nfalsepositiveleaves(1:simul));
      fprintf(fid,'];\n');

      fprintf(fid,'realCPfound = sum(~isnan(estimate''));');
      fclose(fid);
   else
      disp('WARNING: output not written. Set writeoutput=true to activate')
   end
end

if plotsimulationsummary,
   for cp = 1:nCPmu,
      plot(estimate(:,cp),(1:nsimul))
      hold on
      plot(estimate(:,cp),(1:nsimul),'*')
   end
   plot(mu/max(mu)*0.25*nsimul,'g')
   hold off
end

seed = rand('state');
save 'seedsave' seed -ascii -double
