function [h, ht] = CDF_LDL(parLDL,variant)

% CDF_LDL Cohen-Daub.-Feauveau symmetric wavelets with less dissimilar lengths
%   Usage
%     [h ht] = CDF_LDL(parLDL,variant);
%   Inputs
%     parLDL    number of primal vanishing moments
%     variant   1,2 for choice between alternative solutions (default 1)
%   Outputs
%     h    CDF_LDL filter coefficient
%     ht   dual CDF_LDL filter coefficient (bi-orthogonal transform)
%   Description
%     creates dual and primal scaling filter for bi-orthogonal symmetric
%     wavelet of Cohen-Daubechies-Feauveau (CDF)
%     with less dissimilar lengths (LDL), meaning that the number of nonzeros
%     in h and hl is as close as possible to each other, and much closer than
%     in the CDF spline filter case (see help CDFspline)
%   Note
%     This file called by makeWTfilter
%   See also
%     help makeWTfilter
%     help CDFspline

switch parLDL,
case 4,
    
h = [-0.064538882628938
     -0.040689417609558
      0.418092273222212
      0.788485616405664];
ht = [ 0.037828455506996
      -0.023849465019380
      -0.110624404418424
       0.377402855612654
       0.852698679009404];
case 5,
if variant==2,
h = [ 0.007015752324
      0.015436545027
      0.000197904543
      0.043244142922
      0.242786343133
      0.382638624101];
ht = [ 0.038061322045
      -0.083745161515
      -0.257235611210
       0.333745161515
       0.938348578330];
else
h = [  0.009515330511
      -0.001905629356
      -0.096666153049
      -0.066117805605
       0.337150822538
       0.636046869922];
ht = [ 0.028063009296
       0.005620161515
      -0.038511714155
       0.244379838485
       0.520897409718];
end
ht = ht/sum(ht)*sqrt(2); h = h/sum(h)*sqrt(2);
end
h = [h;h(end-1:-1:1)]; ht = [ht;ht(end-1:-1:1)];
h = h'; ht = ht';

% Copyright (c) Maarten Jansen
%
% This software is part of ThreshLab and is copyrighted material. 
