
function psi = WTbasisfunction(M,h,g,sh,sg,scaling)

% WTbasisfunction - ThreshLab/WT/ -- basis function corresponding to filters
%  Usage
%    psi = WTbasisfunction(M,h,g,sh,sg)
%    phi = WTbasisfunction(M,h,sh)
%    phi = WTbasisfunction(M,h,g,sh,sg,true)
%  Inputs
%    M         resolution level of psi (sets lengh of output)
%    L         coarsest level
%    h         Low pass filter
%    g         High pass filter
%    sh        Low pass filter shift (see FWT_BIO, mirrorshift)
%    sg        High pass filter shift (see FWT_BIO, mirrorshift)
%  Outputs
%    psi       wavelet function ("mother" function)
%    phi       scaling function ("father" function)
%  Description
%  Note
%    inputs g,sg are not required for output phi
%  See also:
%    help FWT_BIO
%    help IWT_BIO
%    help mirrorshift

if nargin < 6, scaling = false; end
if nargin < 3, g = 0; end
if nargin < 4, sh = g; g = 0; sg = 0; scaling = true; end
nh = length(h);
ng = length(g);
rjs = 1; 
for j = 1:M,
   rjw = rjs+2^(j-1)*ng-2^(j-1)+1-1;
   rjs = rjs+2^(j-1)*nh-2^(j-1)+1-1;
end
if scaling,
   J = ceil(log2(rjs));
   N = 2^J;
   L = J-M;
   i = ceil(2^(L+1)/4);
else
   J = ceil(log2(rjw));
   N = 2^J;
   L = J-M;
   i = ceil(3*2^(L+1)/4);
end
x0 = zeros(1,N);
x0(i) = 1;
gamma = IWT_BIO(x0,L,h,g,sh,sg);
x = zeros(1,N);
[first, last] = FWTdualsupport(x,L,h,g,sh,sg);
if first(i) > last(i),
   gamma = [gamma(first(i):N) gamma(1:last(i))];
else
   gamma = gamma(first(i):last(i));
end
psi = gamma;

% Copyright (c) Maarten Jansen
% 
% This software is part of ThreshLab and is copyrighted material. 
